/* ******************************************************************************
 * Copyright (c) 2019, 2020 BestSolution.at and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License 2.0 
 * which is available at http://www.eclipse.org/legal/epl-2.0
 *
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Christoph Caks <ccaks@bestsolution.at> - initial API and implementation
 * ******************************************************************************/

#ifndef GL_CONTEXT_GEN_H_
#define GL_CONTEXT_GEN_H_

#include "Export.h"
#include <cstdint>
#include <stddef.h>

namespace driftgl {
	typedef void GLvoid;
	typedef unsigned int GLenum;
	typedef float GLfloat;
	typedef int GLint;
	typedef int GLsizei;
	typedef unsigned int GLbitfield;
	typedef double GLdouble;
	typedef unsigned int GLuint;
	typedef unsigned char GLboolean;
	typedef unsigned char GLubyte;
	typedef char GLchar;
	typedef short GLshort;
	typedef signed char GLbyte;
	typedef unsigned short GLushort;
	
	
	typedef unsigned short GLhalf;
	typedef struct __GLsync *GLsync;
	typedef uint64_t GLuint64;
	typedef int64_t GLint64;
	typedef ptrdiff_t GLsizeiptr;
	typedef ptrdiff_t GLintptr;
	
	typedef void (*GLDEBUGPROC)(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *message, const void *userParam);
	
	
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_BUFFER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_BUFFER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_BUFFER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_FALSE;
	DRIFTGL_EXPORT extern unsigned int GL_TRUE;
	DRIFTGL_EXPORT extern unsigned int GL_POINTS;
	DRIFTGL_EXPORT extern unsigned int GL_LINES;
	DRIFTGL_EXPORT extern unsigned int GL_LINE_LOOP;
	DRIFTGL_EXPORT extern unsigned int GL_LINE_STRIP;
	DRIFTGL_EXPORT extern unsigned int GL_TRIANGLES;
	DRIFTGL_EXPORT extern unsigned int GL_TRIANGLE_STRIP;
	DRIFTGL_EXPORT extern unsigned int GL_TRIANGLE_FAN;
	DRIFTGL_EXPORT extern unsigned int GL_NEVER;
	DRIFTGL_EXPORT extern unsigned int GL_LESS;
	DRIFTGL_EXPORT extern unsigned int GL_EQUAL;
	DRIFTGL_EXPORT extern unsigned int GL_LEQUAL;
	DRIFTGL_EXPORT extern unsigned int GL_GREATER;
	DRIFTGL_EXPORT extern unsigned int GL_NOTEQUAL;
	DRIFTGL_EXPORT extern unsigned int GL_GEQUAL;
	DRIFTGL_EXPORT extern unsigned int GL_ALWAYS;
	DRIFTGL_EXPORT extern unsigned int GL_ZERO;
	DRIFTGL_EXPORT extern unsigned int GL_ONE;
	DRIFTGL_EXPORT extern unsigned int GL_SRC_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_ONE_MINUS_SRC_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_SRC_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_ONE_MINUS_SRC_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_DST_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_ONE_MINUS_DST_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_DST_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_ONE_MINUS_DST_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_SRC_ALPHA_SATURATE;
	DRIFTGL_EXPORT extern unsigned int GL_NONE;
	DRIFTGL_EXPORT extern unsigned int GL_FRONT_LEFT;
	DRIFTGL_EXPORT extern unsigned int GL_FRONT_RIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_BACK_LEFT;
	DRIFTGL_EXPORT extern unsigned int GL_BACK_RIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_FRONT;
	DRIFTGL_EXPORT extern unsigned int GL_BACK;
	DRIFTGL_EXPORT extern unsigned int GL_LEFT;
	DRIFTGL_EXPORT extern unsigned int GL_RIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_FRONT_AND_BACK;
	DRIFTGL_EXPORT extern unsigned int GL_NO_ERROR;
	DRIFTGL_EXPORT extern unsigned int GL_INVALID_ENUM;
	DRIFTGL_EXPORT extern unsigned int GL_INVALID_VALUE;
	DRIFTGL_EXPORT extern unsigned int GL_INVALID_OPERATION;
	DRIFTGL_EXPORT extern unsigned int GL_OUT_OF_MEMORY;
	DRIFTGL_EXPORT extern unsigned int GL_CW;
	DRIFTGL_EXPORT extern unsigned int GL_CCW;
	DRIFTGL_EXPORT extern unsigned int GL_POINT_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_POINT_SIZE_RANGE;
	DRIFTGL_EXPORT extern unsigned int GL_POINT_SIZE_GRANULARITY;
	DRIFTGL_EXPORT extern unsigned int GL_LINE_SMOOTH;
	DRIFTGL_EXPORT extern unsigned int GL_LINE_WIDTH;
	DRIFTGL_EXPORT extern unsigned int GL_LINE_WIDTH_RANGE;
	DRIFTGL_EXPORT extern unsigned int GL_LINE_WIDTH_GRANULARITY;
	DRIFTGL_EXPORT extern unsigned int GL_POLYGON_MODE;
	DRIFTGL_EXPORT extern unsigned int GL_POLYGON_SMOOTH;
	DRIFTGL_EXPORT extern unsigned int GL_CULL_FACE;
	DRIFTGL_EXPORT extern unsigned int GL_CULL_FACE_MODE;
	DRIFTGL_EXPORT extern unsigned int GL_FRONT_FACE;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_RANGE;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_TEST;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_WRITEMASK;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_CLEAR_VALUE;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_FUNC;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_TEST;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_CLEAR_VALUE;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_FUNC;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_VALUE_MASK;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_FAIL;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_PASS_DEPTH_FAIL;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_PASS_DEPTH_PASS;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_REF;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_WRITEMASK;
	DRIFTGL_EXPORT extern unsigned int GL_VIEWPORT;
	DRIFTGL_EXPORT extern unsigned int GL_DITHER;
	DRIFTGL_EXPORT extern unsigned int GL_BLEND_DST;
	DRIFTGL_EXPORT extern unsigned int GL_BLEND_SRC;
	DRIFTGL_EXPORT extern unsigned int GL_BLEND;
	DRIFTGL_EXPORT extern unsigned int GL_LOGIC_OP_MODE;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_READ_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_SCISSOR_BOX;
	DRIFTGL_EXPORT extern unsigned int GL_SCISSOR_TEST;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_CLEAR_VALUE;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_WRITEMASK;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLEBUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_STEREO;
	DRIFTGL_EXPORT extern unsigned int GL_LINE_SMOOTH_HINT;
	DRIFTGL_EXPORT extern unsigned int GL_POLYGON_SMOOTH_HINT;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_SWAP_BYTES;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_LSB_FIRST;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_ROW_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_SKIP_ROWS;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_SKIP_PIXELS;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_ALIGNMENT;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_SWAP_BYTES;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_LSB_FIRST;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_ROW_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_SKIP_ROWS;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_SKIP_PIXELS;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_ALIGNMENT;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TEXTURE_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VIEWPORT_DIMS;
	DRIFTGL_EXPORT extern unsigned int GL_SUBPIXEL_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_1D;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_2D;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_WIDTH;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_HEIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BORDER_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_DONT_CARE;
	DRIFTGL_EXPORT extern unsigned int GL_FASTEST;
	DRIFTGL_EXPORT extern unsigned int GL_NICEST;
	DRIFTGL_EXPORT extern unsigned int GL_BYTE;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_BYTE;
	DRIFTGL_EXPORT extern unsigned int GL_SHORT;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_SHORT;
	DRIFTGL_EXPORT extern unsigned int GL_INT;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT;
	DRIFTGL_EXPORT extern unsigned int GL_CLEAR;
	DRIFTGL_EXPORT extern unsigned int GL_AND;
	DRIFTGL_EXPORT extern unsigned int GL_AND_REVERSE;
	DRIFTGL_EXPORT extern unsigned int GL_COPY;
	DRIFTGL_EXPORT extern unsigned int GL_AND_INVERTED;
	DRIFTGL_EXPORT extern unsigned int GL_NOOP;
	DRIFTGL_EXPORT extern unsigned int GL_XOR;
	DRIFTGL_EXPORT extern unsigned int GL_OR;
	DRIFTGL_EXPORT extern unsigned int GL_NOR;
	DRIFTGL_EXPORT extern unsigned int GL_EQUIV;
	DRIFTGL_EXPORT extern unsigned int GL_INVERT;
	DRIFTGL_EXPORT extern unsigned int GL_OR_REVERSE;
	DRIFTGL_EXPORT extern unsigned int GL_COPY_INVERTED;
	DRIFTGL_EXPORT extern unsigned int GL_OR_INVERTED;
	DRIFTGL_EXPORT extern unsigned int GL_NAND;
	DRIFTGL_EXPORT extern unsigned int GL_SET;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_INDEX;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_COMPONENT;
	DRIFTGL_EXPORT extern unsigned int GL_RED;
	DRIFTGL_EXPORT extern unsigned int GL_GREEN;
	DRIFTGL_EXPORT extern unsigned int GL_BLUE;
	DRIFTGL_EXPORT extern unsigned int GL_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_RGB;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA;
	DRIFTGL_EXPORT extern unsigned int GL_POINT;
	DRIFTGL_EXPORT extern unsigned int GL_LINE;
	DRIFTGL_EXPORT extern unsigned int GL_FILL;
	DRIFTGL_EXPORT extern unsigned int GL_KEEP;
	DRIFTGL_EXPORT extern unsigned int GL_REPLACE;
	DRIFTGL_EXPORT extern unsigned int GL_INCR;
	DRIFTGL_EXPORT extern unsigned int GL_DECR;
	DRIFTGL_EXPORT extern unsigned int GL_VENDOR;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERER;
	DRIFTGL_EXPORT extern unsigned int GL_VERSION;
	DRIFTGL_EXPORT extern unsigned int GL_EXTENSIONS;
	DRIFTGL_EXPORT extern unsigned int GL_NEAREST;
	DRIFTGL_EXPORT extern unsigned int GL_LINEAR;
	DRIFTGL_EXPORT extern unsigned int GL_NEAREST_MIPMAP_NEAREST;
	DRIFTGL_EXPORT extern unsigned int GL_LINEAR_MIPMAP_NEAREST;
	DRIFTGL_EXPORT extern unsigned int GL_NEAREST_MIPMAP_LINEAR;
	DRIFTGL_EXPORT extern unsigned int GL_LINEAR_MIPMAP_LINEAR;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_MAG_FILTER;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_MIN_FILTER;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_WRAP_S;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_WRAP_T;
	DRIFTGL_EXPORT extern unsigned int GL_REPEAT;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_LOGIC_OP;
	DRIFTGL_EXPORT extern unsigned int GL_POLYGON_OFFSET_UNITS;
	DRIFTGL_EXPORT extern unsigned int GL_POLYGON_OFFSET_POINT;
	DRIFTGL_EXPORT extern unsigned int GL_POLYGON_OFFSET_LINE;
	DRIFTGL_EXPORT extern unsigned int GL_POLYGON_OFFSET_FILL;
	DRIFTGL_EXPORT extern unsigned int GL_POLYGON_OFFSET_FACTOR;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BINDING_1D;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BINDING_2D;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_INTERNAL_FORMAT;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_RED_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_GREEN_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BLUE_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_ALPHA_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE;
	DRIFTGL_EXPORT extern unsigned int GL_PROXY_TEXTURE_1D;
	DRIFTGL_EXPORT extern unsigned int GL_PROXY_TEXTURE_2D;
	DRIFTGL_EXPORT extern unsigned int GL_R3_G3_B2;
	DRIFTGL_EXPORT extern unsigned int GL_RGB4;
	DRIFTGL_EXPORT extern unsigned int GL_RGB5;
	DRIFTGL_EXPORT extern unsigned int GL_RGB8;
	DRIFTGL_EXPORT extern unsigned int GL_RGB10;
	DRIFTGL_EXPORT extern unsigned int GL_RGB12;
	DRIFTGL_EXPORT extern unsigned int GL_RGB16;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA2;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA4;
	DRIFTGL_EXPORT extern unsigned int GL_RGB5_A1;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA8;
	DRIFTGL_EXPORT extern unsigned int GL_RGB10_A2;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA12;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA16;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_BYTE_3_3_2;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_SHORT_4_4_4_4;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_SHORT_5_5_5_1;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_8_8_8_8;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_10_10_10_2;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BINDING_3D;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_SKIP_IMAGES;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_IMAGE_HEIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_SKIP_IMAGES;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_IMAGE_HEIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_3D;
	DRIFTGL_EXPORT extern unsigned int GL_PROXY_TEXTURE_3D;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_DEPTH;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_WRAP_R;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_3D_TEXTURE_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_BYTE_2_3_3_REV;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_SHORT_5_6_5;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_SHORT_5_6_5_REV;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_SHORT_4_4_4_4_REV;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_SHORT_1_5_5_5_REV;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_8_8_8_8_REV;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_2_10_10_10_REV;
	DRIFTGL_EXPORT extern unsigned int GL_BGR;
	DRIFTGL_EXPORT extern unsigned int GL_BGRA;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_ELEMENTS_VERTICES;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_ELEMENTS_INDICES;
	DRIFTGL_EXPORT extern unsigned int GL_CLAMP_TO_EDGE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_MIN_LOD;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_MAX_LOD;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BASE_LEVEL;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_MAX_LEVEL;
	DRIFTGL_EXPORT extern unsigned int GL_SMOOTH_POINT_SIZE_RANGE;
	DRIFTGL_EXPORT extern unsigned int GL_SMOOTH_POINT_SIZE_GRANULARITY;
	DRIFTGL_EXPORT extern unsigned int GL_SMOOTH_LINE_WIDTH_RANGE;
	DRIFTGL_EXPORT extern unsigned int GL_SMOOTH_LINE_WIDTH_GRANULARITY;
	DRIFTGL_EXPORT extern unsigned int GL_ALIASED_LINE_WIDTH_RANGE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE0;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE1;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE2;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE3;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE4;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE5;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE6;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE7;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE8;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE9;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE10;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE11;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE12;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE13;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE14;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE15;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE16;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE17;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE18;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE19;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE20;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE21;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE22;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE23;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE24;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE25;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE26;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE27;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE28;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE29;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE30;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE31;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_TEXTURE;
	DRIFTGL_EXPORT extern unsigned int GL_MULTISAMPLE;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLE_ALPHA_TO_COVERAGE;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLE_ALPHA_TO_ONE;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLE_COVERAGE;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLE_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLES;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLE_COVERAGE_VALUE;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLE_COVERAGE_INVERT;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_CUBE_MAP;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BINDING_CUBE_MAP;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_CUBE_MAP_POSITIVE_X;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_CUBE_MAP_NEGATIVE_X;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_CUBE_MAP_POSITIVE_Y;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_CUBE_MAP_NEGATIVE_Y;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_CUBE_MAP_POSITIVE_Z;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_CUBE_MAP_NEGATIVE_Z;
	DRIFTGL_EXPORT extern unsigned int GL_PROXY_TEXTURE_CUBE_MAP;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_CUBE_MAP_TEXTURE_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RGB;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RGBA;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_COMPRESSION_HINT;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_COMPRESSED_IMAGE_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_COMPRESSED;
	DRIFTGL_EXPORT extern unsigned int GL_NUM_COMPRESSED_TEXTURE_FORMATS;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_TEXTURE_FORMATS;
	DRIFTGL_EXPORT extern unsigned int GL_CLAMP_TO_BORDER;
	DRIFTGL_EXPORT extern unsigned int GL_BLEND_DST_RGB;
	DRIFTGL_EXPORT extern unsigned int GL_BLEND_SRC_RGB;
	DRIFTGL_EXPORT extern unsigned int GL_BLEND_DST_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_BLEND_SRC_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_POINT_FADE_THRESHOLD_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_COMPONENT16;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_COMPONENT24;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_COMPONENT32;
	DRIFTGL_EXPORT extern unsigned int GL_MIRRORED_REPEAT;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TEXTURE_LOD_BIAS;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_LOD_BIAS;
	DRIFTGL_EXPORT extern unsigned int GL_INCR_WRAP;
	DRIFTGL_EXPORT extern unsigned int GL_DECR_WRAP;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_DEPTH_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_COMPARE_MODE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_COMPARE_FUNC;
	DRIFTGL_EXPORT extern unsigned int GL_BLEND_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_BLEND_EQUATION;
	DRIFTGL_EXPORT extern unsigned int GL_CONSTANT_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_ONE_MINUS_CONSTANT_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_CONSTANT_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_ONE_MINUS_CONSTANT_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_FUNC_ADD;
	DRIFTGL_EXPORT extern unsigned int GL_FUNC_REVERSE_SUBTRACT;
	DRIFTGL_EXPORT extern unsigned int GL_FUNC_SUBTRACT;
	DRIFTGL_EXPORT extern unsigned int GL_MIN;
	DRIFTGL_EXPORT extern unsigned int GL_MAX;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_USAGE;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_COUNTER_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_CURRENT_QUERY;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_RESULT;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_RESULT_AVAILABLE;
	DRIFTGL_EXPORT extern unsigned int GL_ARRAY_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_ELEMENT_ARRAY_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_ARRAY_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_ELEMENT_ARRAY_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_READ_ONLY;
	DRIFTGL_EXPORT extern unsigned int GL_WRITE_ONLY;
	DRIFTGL_EXPORT extern unsigned int GL_READ_WRITE;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_ACCESS;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_MAPPED;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_MAP_POINTER;
	DRIFTGL_EXPORT extern unsigned int GL_STREAM_DRAW;
	DRIFTGL_EXPORT extern unsigned int GL_STREAM_READ;
	DRIFTGL_EXPORT extern unsigned int GL_STREAM_COPY;
	DRIFTGL_EXPORT extern unsigned int GL_STATIC_DRAW;
	DRIFTGL_EXPORT extern unsigned int GL_STATIC_READ;
	DRIFTGL_EXPORT extern unsigned int GL_STATIC_COPY;
	DRIFTGL_EXPORT extern unsigned int GL_DYNAMIC_DRAW;
	DRIFTGL_EXPORT extern unsigned int GL_DYNAMIC_READ;
	DRIFTGL_EXPORT extern unsigned int GL_DYNAMIC_COPY;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLES_PASSED;
	DRIFTGL_EXPORT extern unsigned int GL_SRC1_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_BLEND_EQUATION_RGB;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_ARRAY_ENABLED;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_ARRAY_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_ARRAY_STRIDE;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_ARRAY_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_CURRENT_VERTEX_ATTRIB;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_PROGRAM_POINT_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_ARRAY_POINTER;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_BACK_FUNC;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_BACK_FAIL;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_BACK_PASS_DEPTH_FAIL;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_BACK_PASS_DEPTH_PASS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_DRAW_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER0;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER1;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER2;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER3;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER4;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER5;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER6;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER7;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER8;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER9;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER10;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER11;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER12;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER13;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER14;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_BUFFER15;
	DRIFTGL_EXPORT extern unsigned int GL_BLEND_EQUATION_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_ATTRIBS;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_ARRAY_NORMALIZED;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TEXTURE_IMAGE_UNITS;
	DRIFTGL_EXPORT extern unsigned int GL_FRAGMENT_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAGMENT_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VARYING_FLOATS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_VEC2;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_VEC3;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_VEC4;
	DRIFTGL_EXPORT extern unsigned int GL_INT_VEC2;
	DRIFTGL_EXPORT extern unsigned int GL_INT_VEC3;
	DRIFTGL_EXPORT extern unsigned int GL_INT_VEC4;
	DRIFTGL_EXPORT extern unsigned int GL_BOOL;
	DRIFTGL_EXPORT extern unsigned int GL_BOOL_VEC2;
	DRIFTGL_EXPORT extern unsigned int GL_BOOL_VEC3;
	DRIFTGL_EXPORT extern unsigned int GL_BOOL_VEC4;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_MAT2;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_MAT3;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_MAT4;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_1D;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_2D;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_3D;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_CUBE;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_1D_SHADOW;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_2D_SHADOW;
	DRIFTGL_EXPORT extern unsigned int GL_DELETE_STATUS;
	DRIFTGL_EXPORT extern unsigned int GL_COMPILE_STATUS;
	DRIFTGL_EXPORT extern unsigned int GL_LINK_STATUS;
	DRIFTGL_EXPORT extern unsigned int GL_VALIDATE_STATUS;
	DRIFTGL_EXPORT extern unsigned int GL_INFO_LOG_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_ATTACHED_SHADERS;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_UNIFORMS;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_UNIFORM_MAX_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_SOURCE_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_ATTRIBUTES;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_ATTRIBUTE_MAX_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_FRAGMENT_SHADER_DERIVATIVE_HINT;
	DRIFTGL_EXPORT extern unsigned int GL_SHADING_LANGUAGE_VERSION;
	DRIFTGL_EXPORT extern unsigned int GL_CURRENT_PROGRAM;
	DRIFTGL_EXPORT extern unsigned int GL_POINT_SPRITE_COORD_ORIGIN;
	DRIFTGL_EXPORT extern unsigned int GL_LOWER_LEFT;
	DRIFTGL_EXPORT extern unsigned int GL_UPPER_LEFT;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_BACK_REF;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_BACK_VALUE_MASK;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_BACK_WRITEMASK;
	DRIFTGL_EXPORT extern unsigned int GL_PIXEL_PACK_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_PIXEL_UNPACK_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_PIXEL_PACK_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_PIXEL_UNPACK_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_MAT2x3;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_MAT2x4;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_MAT3x2;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_MAT3x4;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_MAT4x2;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_MAT4x3;
	DRIFTGL_EXPORT extern unsigned int GL_SRGB;
	DRIFTGL_EXPORT extern unsigned int GL_SRGB8;
	DRIFTGL_EXPORT extern unsigned int GL_SRGB_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_SRGB8_ALPHA8;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_SRGB;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_SRGB_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_COMPARE_REF_TO_TEXTURE;
	DRIFTGL_EXPORT extern unsigned int GL_CLIP_DISTANCE0;
	DRIFTGL_EXPORT extern unsigned int GL_CLIP_DISTANCE1;
	DRIFTGL_EXPORT extern unsigned int GL_CLIP_DISTANCE2;
	DRIFTGL_EXPORT extern unsigned int GL_CLIP_DISTANCE3;
	DRIFTGL_EXPORT extern unsigned int GL_CLIP_DISTANCE4;
	DRIFTGL_EXPORT extern unsigned int GL_CLIP_DISTANCE5;
	DRIFTGL_EXPORT extern unsigned int GL_CLIP_DISTANCE6;
	DRIFTGL_EXPORT extern unsigned int GL_CLIP_DISTANCE7;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_CLIP_DISTANCES;
	DRIFTGL_EXPORT extern unsigned int GL_MAJOR_VERSION;
	DRIFTGL_EXPORT extern unsigned int GL_MINOR_VERSION;
	DRIFTGL_EXPORT extern unsigned int GL_NUM_EXTENSIONS;
	DRIFTGL_EXPORT extern unsigned int GL_CONTEXT_FLAGS;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RED;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RG;
	DRIFTGL_EXPORT extern unsigned int GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA32F;
	DRIFTGL_EXPORT extern unsigned int GL_RGB32F;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA16F;
	DRIFTGL_EXPORT extern unsigned int GL_RGB16F;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_ARRAY_INTEGER;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_ARRAY_TEXTURE_LAYERS;
	DRIFTGL_EXPORT extern unsigned int GL_MIN_PROGRAM_TEXEL_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_PROGRAM_TEXEL_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_CLAMP_READ_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_FIXED_ONLY;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VARYING_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_1D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_PROXY_TEXTURE_1D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_2D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_PROXY_TEXTURE_2D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BINDING_1D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BINDING_2D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_R11F_G11F_B10F;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_10F_11F_11F_REV;
	DRIFTGL_EXPORT extern unsigned int GL_RGB9_E5;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_5_9_9_9_REV;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_SHARED_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_BUFFER_MODE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_VARYINGS;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_BUFFER_START;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_BUFFER_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_PRIMITIVES_GENERATED;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN;
	DRIFTGL_EXPORT extern unsigned int GL_RASTERIZER_DISCARD;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS;
	DRIFTGL_EXPORT extern unsigned int GL_INTERLEAVED_ATTRIBS;
	DRIFTGL_EXPORT extern unsigned int GL_SEPARATE_ATTRIBS;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA32UI;
	DRIFTGL_EXPORT extern unsigned int GL_RGB32UI;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA16UI;
	DRIFTGL_EXPORT extern unsigned int GL_RGB16UI;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA8UI;
	DRIFTGL_EXPORT extern unsigned int GL_RGB8UI;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA32I;
	DRIFTGL_EXPORT extern unsigned int GL_RGB32I;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA16I;
	DRIFTGL_EXPORT extern unsigned int GL_RGB16I;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA8I;
	DRIFTGL_EXPORT extern unsigned int GL_RGB8I;
	DRIFTGL_EXPORT extern unsigned int GL_RED_INTEGER;
	DRIFTGL_EXPORT extern unsigned int GL_GREEN_INTEGER;
	DRIFTGL_EXPORT extern unsigned int GL_BLUE_INTEGER;
	DRIFTGL_EXPORT extern unsigned int GL_RGB_INTEGER;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA_INTEGER;
	DRIFTGL_EXPORT extern unsigned int GL_BGR_INTEGER;
	DRIFTGL_EXPORT extern unsigned int GL_BGRA_INTEGER;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_1D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_2D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_1D_ARRAY_SHADOW;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_2D_ARRAY_SHADOW;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_CUBE_SHADOW;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_VEC2;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_VEC3;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_VEC4;
	DRIFTGL_EXPORT extern unsigned int GL_INT_SAMPLER_1D;
	DRIFTGL_EXPORT extern unsigned int GL_INT_SAMPLER_2D;
	DRIFTGL_EXPORT extern unsigned int GL_INT_SAMPLER_3D;
	DRIFTGL_EXPORT extern unsigned int GL_INT_SAMPLER_CUBE;
	DRIFTGL_EXPORT extern unsigned int GL_INT_SAMPLER_1D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_INT_SAMPLER_2D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_SAMPLER_1D;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_SAMPLER_2D;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_SAMPLER_3D;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_SAMPLER_CUBE;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_SAMPLER_1D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_SAMPLER_2D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_WAIT;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_NO_WAIT;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_BY_REGION_WAIT;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_BY_REGION_NO_WAIT;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_ACCESS_FLAGS;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_MAP_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_MAP_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_COMPONENT32F;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH32F_STENCIL8;
	DRIFTGL_EXPORT extern unsigned int GL_FLOAT_32_UNSIGNED_INT_24_8_REV;
	DRIFTGL_EXPORT extern unsigned int GL_INVALID_FRAMEBUFFER_OPERATION;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_DEFAULT;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_UNDEFINED;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_STENCIL_ATTACHMENT;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_RENDERBUFFER_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_STENCIL;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_24_8;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH24_STENCIL8;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_STENCIL_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_RED_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_GREEN_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BLUE_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_ALPHA_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_DEPTH_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_NORMALIZED;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_FRAMEBUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_READ_FRAMEBUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_FRAMEBUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_READ_FRAMEBUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER_SAMPLES;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_COMPLETE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_UNSUPPORTED;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COLOR_ATTACHMENTS;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT0;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT1;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT2;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT3;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT4;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT5;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT6;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT7;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT8;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT9;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT10;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT11;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT12;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT13;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT14;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT15;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT16;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT17;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT18;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT19;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT20;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT21;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT22;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT23;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT24;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT25;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT26;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT27;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT28;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT29;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT30;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ATTACHMENT31;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_ATTACHMENT;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_ATTACHMENT;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER_WIDTH;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER_HEIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER_INTERNAL_FORMAT;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_INDEX1;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_INDEX4;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_INDEX8;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_INDEX16;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER_RED_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER_GREEN_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER_BLUE_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER_ALPHA_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER_DEPTH_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_RENDERBUFFER_STENCIL_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_SAMPLES;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_SRGB;
	DRIFTGL_EXPORT extern unsigned int GL_HALF_FLOAT;
	DRIFTGL_EXPORT extern unsigned int GL_MAP_READ_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_MAP_WRITE_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_MAP_INVALIDATE_RANGE_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_MAP_INVALIDATE_BUFFER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_MAP_FLUSH_EXPLICIT_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_MAP_UNSYNCHRONIZED_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RED_RGTC1;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_SIGNED_RED_RGTC1;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RG_RGTC2;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_SIGNED_RG_RGTC2;
	DRIFTGL_EXPORT extern unsigned int GL_RG;
	DRIFTGL_EXPORT extern unsigned int GL_RG_INTEGER;
	DRIFTGL_EXPORT extern unsigned int GL_R8;
	DRIFTGL_EXPORT extern unsigned int GL_R16;
	DRIFTGL_EXPORT extern unsigned int GL_RG8;
	DRIFTGL_EXPORT extern unsigned int GL_RG16;
	DRIFTGL_EXPORT extern unsigned int GL_R16F;
	DRIFTGL_EXPORT extern unsigned int GL_R32F;
	DRIFTGL_EXPORT extern unsigned int GL_RG16F;
	DRIFTGL_EXPORT extern unsigned int GL_RG32F;
	DRIFTGL_EXPORT extern unsigned int GL_R8I;
	DRIFTGL_EXPORT extern unsigned int GL_R8UI;
	DRIFTGL_EXPORT extern unsigned int GL_R16I;
	DRIFTGL_EXPORT extern unsigned int GL_R16UI;
	DRIFTGL_EXPORT extern unsigned int GL_R32I;
	DRIFTGL_EXPORT extern unsigned int GL_R32UI;
	DRIFTGL_EXPORT extern unsigned int GL_RG8I;
	DRIFTGL_EXPORT extern unsigned int GL_RG8UI;
	DRIFTGL_EXPORT extern unsigned int GL_RG16I;
	DRIFTGL_EXPORT extern unsigned int GL_RG16UI;
	DRIFTGL_EXPORT extern unsigned int GL_RG32I;
	DRIFTGL_EXPORT extern unsigned int GL_RG32UI;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ARRAY_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_2D_RECT;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_2D_RECT_SHADOW;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_INT_SAMPLER_2D_RECT;
	DRIFTGL_EXPORT extern unsigned int GL_INT_SAMPLER_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_SAMPLER_2D_RECT;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_SAMPLER_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TEXTURE_BUFFER_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BINDING_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BUFFER_DATA_STORE_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_RECTANGLE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BINDING_RECTANGLE;
	DRIFTGL_EXPORT extern unsigned int GL_PROXY_TEXTURE_RECTANGLE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_RECTANGLE_TEXTURE_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_R8_SNORM;
	DRIFTGL_EXPORT extern unsigned int GL_RG8_SNORM;
	DRIFTGL_EXPORT extern unsigned int GL_RGB8_SNORM;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA8_SNORM;
	DRIFTGL_EXPORT extern unsigned int GL_R16_SNORM;
	DRIFTGL_EXPORT extern unsigned int GL_RG16_SNORM;
	DRIFTGL_EXPORT extern unsigned int GL_RGB16_SNORM;
	DRIFTGL_EXPORT extern unsigned int GL_RGBA16_SNORM;
	DRIFTGL_EXPORT extern unsigned int GL_SIGNED_NORMALIZED;
	DRIFTGL_EXPORT extern unsigned int GL_PRIMITIVE_RESTART;
	DRIFTGL_EXPORT extern unsigned int GL_PRIMITIVE_RESTART_INDEX;
	DRIFTGL_EXPORT extern unsigned int GL_COPY_READ_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_COPY_WRITE_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BUFFER_START;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BUFFER_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_UNIFORM_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_UNIFORM_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAGMENT_UNIFORM_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_UNIFORM_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_UNIFORM_BUFFER_BINDINGS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_UNIFORM_BLOCK_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_UNIFORM_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_NAME_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_INDEX;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_ARRAY_STRIDE;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_MATRIX_STRIDE;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_IS_ROW_MAJOR;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_DATA_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_NAME_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_INVALID_INDEX;
	DRIFTGL_EXPORT extern unsigned int GL_CONTEXT_CORE_PROFILE_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_CONTEXT_COMPATIBILITY_PROFILE_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_LINES_ADJACENCY;
	DRIFTGL_EXPORT extern unsigned int GL_LINE_STRIP_ADJACENCY;
	DRIFTGL_EXPORT extern unsigned int GL_TRIANGLES_ADJACENCY;
	DRIFTGL_EXPORT extern unsigned int GL_TRIANGLE_STRIP_ADJACENCY;
	DRIFTGL_EXPORT extern unsigned int GL_PROGRAM_POINT_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_ATTACHMENT_LAYERED;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS;
	DRIFTGL_EXPORT extern unsigned int GL_GEOMETRY_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_GEOMETRY_VERTICES_OUT;
	DRIFTGL_EXPORT extern unsigned int GL_GEOMETRY_INPUT_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_GEOMETRY_OUTPUT_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_OUTPUT_VERTICES;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_OUTPUT_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_INPUT_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_OUTPUT_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAGMENT_INPUT_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_CONTEXT_PROFILE_MASK;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_CLAMP;
	DRIFTGL_EXPORT extern unsigned int GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION;
	DRIFTGL_EXPORT extern unsigned int GL_FIRST_VERTEX_CONVENTION;
	DRIFTGL_EXPORT extern unsigned int GL_LAST_VERTEX_CONVENTION;
	DRIFTGL_EXPORT extern unsigned int GL_PROVOKING_VERTEX;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_CUBE_MAP_SEAMLESS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_SERVER_WAIT_TIMEOUT;
	DRIFTGL_EXPORT extern unsigned int GL_OBJECT_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_SYNC_CONDITION;
	DRIFTGL_EXPORT extern unsigned int GL_SYNC_STATUS;
	DRIFTGL_EXPORT extern unsigned int GL_SYNC_FLAGS;
	DRIFTGL_EXPORT extern unsigned int GL_SYNC_FENCE;
	DRIFTGL_EXPORT extern unsigned int GL_SYNC_GPU_COMMANDS_COMPLETE;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNALED;
	DRIFTGL_EXPORT extern unsigned int GL_SIGNALED;
	DRIFTGL_EXPORT extern unsigned int GL_ALREADY_SIGNALED;
	DRIFTGL_EXPORT extern unsigned int GL_TIMEOUT_EXPIRED;
	DRIFTGL_EXPORT extern unsigned int GL_CONDITION_SATISFIED;
	DRIFTGL_EXPORT extern unsigned int GL_WAIT_FAILED;
	DRIFTGL_EXPORT extern unsigned long long GL_TIMEOUT_IGNORED;
	DRIFTGL_EXPORT extern unsigned int GL_SYNC_FLUSH_COMMANDS_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLE_POSITION;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLE_MASK;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLE_MASK_VALUE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_SAMPLE_MASK_WORDS;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_2D_MULTISAMPLE;
	DRIFTGL_EXPORT extern unsigned int GL_PROXY_TEXTURE_2D_MULTISAMPLE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_2D_MULTISAMPLE_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BINDING_2D_MULTISAMPLE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_SAMPLES;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_FIXED_SAMPLE_LOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_2D_MULTISAMPLE;
	DRIFTGL_EXPORT extern unsigned int GL_INT_SAMPLER_2D_MULTISAMPLE;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_2D_MULTISAMPLE_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COLOR_TEXTURE_SAMPLES;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_DEPTH_TEXTURE_SAMPLES;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_INTEGER_SAMPLES;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_ARRAY_DIVISOR;
	DRIFTGL_EXPORT extern unsigned int GL_SRC1_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_ONE_MINUS_SRC1_COLOR;
	DRIFTGL_EXPORT extern unsigned int GL_ONE_MINUS_SRC1_ALPHA;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_DUAL_SOURCE_DRAW_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_ANY_SAMPLES_PASSED;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_RGB10_A2UI;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_SWIZZLE_R;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_SWIZZLE_G;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_SWIZZLE_B;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_SWIZZLE_A;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_SWIZZLE_RGBA;
	DRIFTGL_EXPORT extern unsigned int GL_TIME_ELAPSED;
	DRIFTGL_EXPORT extern unsigned int GL_TIMESTAMP;
	DRIFTGL_EXPORT extern unsigned int GL_INT_2_10_10_10_REV;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLE_SHADING;
	DRIFTGL_EXPORT extern unsigned int GL_MIN_SAMPLE_SHADING_VALUE;
	DRIFTGL_EXPORT extern unsigned int GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_CUBE_MAP_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BINDING_CUBE_MAP_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_PROXY_TEXTURE_CUBE_MAP_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_CUBE_MAP_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW;
	DRIFTGL_EXPORT extern unsigned int GL_INT_SAMPLER_CUBE_MAP_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_INDIRECT_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_DRAW_INDIRECT_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_GEOMETRY_SHADER_INVOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_SHADER_INVOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_MIN_FRAGMENT_INTERPOLATION_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAGMENT_INTERPOLATION_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_FRAGMENT_INTERPOLATION_OFFSET_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_STREAMS;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_VEC2;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_VEC3;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_VEC4;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_MAT2;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_MAT3;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_MAT4;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_MAT2x3;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_MAT2x4;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_MAT3x2;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_MAT3x4;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_MAT4x2;
	DRIFTGL_EXPORT extern unsigned int GL_DOUBLE_MAT4x3;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_SUBROUTINES;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_SUBROUTINE_UNIFORMS;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_SUBROUTINE_UNIFORM_LOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_SUBROUTINE_MAX_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_SUBROUTINE_UNIFORM_MAX_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_SUBROUTINES;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_SUBROUTINE_UNIFORM_LOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_NUM_COMPATIBLE_SUBROUTINES;
	DRIFTGL_EXPORT extern unsigned int GL_COMPATIBLE_SUBROUTINES;
	DRIFTGL_EXPORT extern unsigned int GL_PATCHES;
	DRIFTGL_EXPORT extern unsigned int GL_PATCH_VERTICES;
	DRIFTGL_EXPORT extern unsigned int GL_PATCH_DEFAULT_INNER_LEVEL;
	DRIFTGL_EXPORT extern unsigned int GL_PATCH_DEFAULT_OUTER_LEVEL;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_CONTROL_OUTPUT_VERTICES;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_GEN_MODE;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_GEN_SPACING;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_GEN_VERTEX_ORDER;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_GEN_POINT_MODE;
	DRIFTGL_EXPORT extern unsigned int GL_ISOLINES;
	DRIFTGL_EXPORT extern unsigned int GL_QUADS;
	DRIFTGL_EXPORT extern unsigned int GL_FRACTIONAL_ODD;
	DRIFTGL_EXPORT extern unsigned int GL_FRACTIONAL_EVEN;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_PATCH_VERTICES;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_GEN_LEVEL;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_PATCH_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_CONTROL_INPUT_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_CONTROL_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_EVALUATION_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_EVALUATION_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_CONTROL_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TRANSFORM_FEEDBACK_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_FIXED;
	DRIFTGL_EXPORT extern unsigned int GL_IMPLEMENTATION_COLOR_READ_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_IMPLEMENTATION_COLOR_READ_FORMAT;
	DRIFTGL_EXPORT extern unsigned int GL_LOW_FLOAT;
	DRIFTGL_EXPORT extern unsigned int GL_MEDIUM_FLOAT;
	DRIFTGL_EXPORT extern unsigned int GL_HIGH_FLOAT;
	DRIFTGL_EXPORT extern unsigned int GL_LOW_INT;
	DRIFTGL_EXPORT extern unsigned int GL_MEDIUM_INT;
	DRIFTGL_EXPORT extern unsigned int GL_HIGH_INT;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_COMPILER;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_BINARY_FORMATS;
	DRIFTGL_EXPORT extern unsigned int GL_NUM_SHADER_BINARY_FORMATS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_UNIFORM_VECTORS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VARYING_VECTORS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAGMENT_UNIFORM_VECTORS;
	DRIFTGL_EXPORT extern unsigned int GL_RGB565;
	DRIFTGL_EXPORT extern unsigned int GL_PROGRAM_BINARY_RETRIEVABLE_HINT;
	DRIFTGL_EXPORT extern unsigned int GL_PROGRAM_BINARY_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_NUM_PROGRAM_BINARY_FORMATS;
	DRIFTGL_EXPORT extern unsigned int GL_PROGRAM_BINARY_FORMATS;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_SHADER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_FRAGMENT_SHADER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_GEOMETRY_SHADER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_CONTROL_SHADER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_EVALUATION_SHADER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_ALL_SHADER_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_PROGRAM_SEPARABLE;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_PROGRAM;
	DRIFTGL_EXPORT extern unsigned int GL_PROGRAM_PIPELINE_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VIEWPORTS;
	DRIFTGL_EXPORT extern unsigned int GL_VIEWPORT_SUBPIXEL_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_VIEWPORT_BOUNDS_RANGE;
	DRIFTGL_EXPORT extern unsigned int GL_LAYER_PROVOKING_VERTEX;
	DRIFTGL_EXPORT extern unsigned int GL_VIEWPORT_INDEX_PROVOKING_VERTEX;
	DRIFTGL_EXPORT extern unsigned int GL_UNDEFINED_VERTEX;
	DRIFTGL_EXPORT extern unsigned int GL_COPY_READ_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_COPY_WRITE_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_ACTIVE;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_PAUSED;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_COMPRESSED_BLOCK_WIDTH;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_COMPRESSED_BLOCK_HEIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_COMPRESSED_BLOCK_DEPTH;
	DRIFTGL_EXPORT extern unsigned int GL_UNPACK_COMPRESSED_BLOCK_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_COMPRESSED_BLOCK_WIDTH;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_COMPRESSED_BLOCK_HEIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_COMPRESSED_BLOCK_DEPTH;
	DRIFTGL_EXPORT extern unsigned int GL_PACK_COMPRESSED_BLOCK_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_NUM_SAMPLE_COUNTS;
	DRIFTGL_EXPORT extern unsigned int GL_MIN_MAP_BUFFER_ALIGNMENT;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_START;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_DATA_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTER_INDICES;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_VERTEX_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_CONTROL_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_EVALUATION_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_GEOMETRY_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_FRAGMENT_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_ATOMIC_COUNTER_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAGMENT_ATOMIC_COUNTER_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_ATOMIC_COUNTER_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_ATOMIC_COUNTERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_ATOMIC_COUNTERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAGMENT_ATOMIC_COUNTERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_ATOMIC_COUNTERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_ATOMIC_COUNTER_BUFFER_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_ATOMIC_COUNTER_BUFFER_BINDINGS;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_ATOMIC_COUNTER_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_ATOMIC_COUNTER_BUFFER_INDEX;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_ATOMIC_COUNTER;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_ELEMENT_ARRAY_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_FETCH_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_IMAGE_ACCESS_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_COMMAND_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_PIXEL_BUFFER_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_UPDATE_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_UPDATE_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_ALL_BARRIER_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_IMAGE_UNITS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_BINDING_NAME;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_BINDING_LEVEL;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_BINDING_LAYERED;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_BINDING_LAYER;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_BINDING_ACCESS;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_1D;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_2D;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_3D;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_2D_RECT;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CUBE;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_1D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_2D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CUBE_MAP_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_2D_MULTISAMPLE;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_2D_MULTISAMPLE_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_INT_IMAGE_1D;
	DRIFTGL_EXPORT extern unsigned int GL_INT_IMAGE_2D;
	DRIFTGL_EXPORT extern unsigned int GL_INT_IMAGE_3D;
	DRIFTGL_EXPORT extern unsigned int GL_INT_IMAGE_2D_RECT;
	DRIFTGL_EXPORT extern unsigned int GL_INT_IMAGE_CUBE;
	DRIFTGL_EXPORT extern unsigned int GL_INT_IMAGE_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_INT_IMAGE_1D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_INT_IMAGE_2D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_INT_IMAGE_CUBE_MAP_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_INT_IMAGE_2D_MULTISAMPLE;
	DRIFTGL_EXPORT extern unsigned int GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_IMAGE_1D;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_IMAGE_2D;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_IMAGE_3D;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_IMAGE_2D_RECT;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_IMAGE_CUBE;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_IMAGE_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_IMAGE_1D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_IMAGE_2D_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE;
	DRIFTGL_EXPORT extern unsigned int GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_IMAGE_SAMPLES;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_BINDING_FORMAT;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_FORMAT_COMPATIBILITY_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_FORMAT_COMPATIBILITY_BY_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_FORMAT_COMPATIBILITY_BY_CLASS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_IMAGE_UNIFORMS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_IMAGE_UNIFORMS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAGMENT_IMAGE_UNIFORMS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_IMAGE_UNIFORMS;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RGBA_BPTC_UNORM;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_IMMUTABLE_FORMAT;
	DRIFTGL_EXPORT extern unsigned int GL_NUM_SHADING_LANGUAGE_VERSIONS;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_ARRAY_LONG;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RGB8_ETC2;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_SRGB8_ETC2;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RGBA8_ETC2_EAC;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_R11_EAC;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_SIGNED_R11_EAC;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_RG11_EAC;
	DRIFTGL_EXPORT extern unsigned int GL_COMPRESSED_SIGNED_RG11_EAC;
	DRIFTGL_EXPORT extern unsigned int GL_PRIMITIVE_RESTART_FIXED_INDEX;
	DRIFTGL_EXPORT extern unsigned int GL_ANY_SAMPLES_PASSED_CONSERVATIVE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_ELEMENT_INDEX;
	DRIFTGL_EXPORT extern unsigned int GL_COMPUTE_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMPUTE_UNIFORM_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMPUTE_IMAGE_UNIFORMS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMPUTE_SHARED_MEMORY_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMPUTE_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMPUTE_ATOMIC_COUNTERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMPUTE_WORK_GROUP_COUNT;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMPUTE_WORK_GROUP_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_COMPUTE_WORK_GROUP_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK_REFERENCED_BY_COMPUTE_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_COMPUTE_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_DISPATCH_INDIRECT_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_DISPATCH_INDIRECT_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_COMPUTE_SHADER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_OUTPUT_SYNCHRONOUS;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_CALLBACK_FUNCTION;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_CALLBACK_USER_PARAM;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_SOURCE_API;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_SOURCE_WINDOW_SYSTEM;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_SOURCE_SHADER_COMPILER;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_SOURCE_THIRD_PARTY;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_SOURCE_APPLICATION;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_SOURCE_OTHER;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_TYPE_ERROR;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_TYPE_PORTABILITY;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_TYPE_PERFORMANCE;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_TYPE_OTHER;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_DEBUG_MESSAGE_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_DEBUG_LOGGED_MESSAGES;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_LOGGED_MESSAGES;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_SEVERITY_HIGH;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_SEVERITY_MEDIUM;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_SEVERITY_LOW;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_TYPE_MARKER;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_TYPE_PUSH_GROUP;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_TYPE_POP_GROUP;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_SEVERITY_NOTIFICATION;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_DEBUG_GROUP_STACK_DEPTH;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_GROUP_STACK_DEPTH;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_PROGRAM;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ARRAY;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY;
	DRIFTGL_EXPORT extern unsigned int GL_PROGRAM_PIPELINE;
	DRIFTGL_EXPORT extern unsigned int GL_SAMPLER;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_LABEL_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_DEBUG_OUTPUT;
	DRIFTGL_EXPORT extern unsigned int GL_CONTEXT_FLAG_DEBUG_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_UNIFORM_LOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_DEFAULT_WIDTH;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_DEFAULT_HEIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_DEFAULT_LAYERS;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_DEFAULT_SAMPLES;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAMEBUFFER_WIDTH;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAMEBUFFER_HEIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAMEBUFFER_LAYERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAMEBUFFER_SAMPLES;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_SUPPORTED;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_PREFERRED;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_RED_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_GREEN_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_BLUE_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_ALPHA_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_DEPTH_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_STENCIL_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_SHARED_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_RED_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_GREEN_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_BLUE_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_ALPHA_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_DEPTH_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_INTERNALFORMAT_STENCIL_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_WIDTH;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_HEIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_DEPTH;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_LAYERS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_DIMENSIONS;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_COMPONENTS;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_RENDERABLE;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_RENDERABLE;
	DRIFTGL_EXPORT extern unsigned int GL_STENCIL_RENDERABLE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_RENDERABLE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_RENDERABLE_LAYERED;
	DRIFTGL_EXPORT extern unsigned int GL_FRAMEBUFFER_BLEND;
	DRIFTGL_EXPORT extern unsigned int GL_READ_PIXELS;
	DRIFTGL_EXPORT extern unsigned int GL_READ_PIXELS_FORMAT;
	DRIFTGL_EXPORT extern unsigned int GL_READ_PIXELS_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_IMAGE_FORMAT;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_IMAGE_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_GET_TEXTURE_IMAGE_FORMAT;
	DRIFTGL_EXPORT extern unsigned int GL_GET_TEXTURE_IMAGE_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_MIPMAP;
	DRIFTGL_EXPORT extern unsigned int GL_MANUAL_GENERATE_MIPMAP;
	DRIFTGL_EXPORT extern unsigned int GL_AUTO_GENERATE_MIPMAP;
	DRIFTGL_EXPORT extern unsigned int GL_COLOR_ENCODING;
	DRIFTGL_EXPORT extern unsigned int GL_SRGB_READ;
	DRIFTGL_EXPORT extern unsigned int GL_SRGB_WRITE;
	DRIFTGL_EXPORT extern unsigned int GL_FILTER;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_TEXTURE;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_CONTROL_TEXTURE;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_EVALUATION_TEXTURE;
	DRIFTGL_EXPORT extern unsigned int GL_GEOMETRY_TEXTURE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAGMENT_TEXTURE;
	DRIFTGL_EXPORT extern unsigned int GL_COMPUTE_TEXTURE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_SHADOW;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_GATHER;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_GATHER_SHADOW;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_IMAGE_LOAD;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_IMAGE_STORE;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_IMAGE_ATOMIC;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_TEXEL_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_COMPATIBILITY_CLASS;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_PIXEL_FORMAT;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_PIXEL_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_TEST;
	DRIFTGL_EXPORT extern unsigned int GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_TEST;
	DRIFTGL_EXPORT extern unsigned int GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_WRITE;
	DRIFTGL_EXPORT extern unsigned int GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_WRITE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_COMPRESSED_BLOCK_WIDTH;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_COMPRESSED_BLOCK_HEIGHT;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_COMPRESSED_BLOCK_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_CLEAR_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_VIEW;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_COMPATIBILITY_CLASS;
	DRIFTGL_EXPORT extern unsigned int GL_FULL_SUPPORT;
	DRIFTGL_EXPORT extern unsigned int GL_CAVEAT_SUPPORT;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CLASS_4_X_32;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CLASS_2_X_32;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CLASS_1_X_32;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CLASS_4_X_16;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CLASS_2_X_16;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CLASS_1_X_16;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CLASS_4_X_8;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CLASS_2_X_8;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CLASS_1_X_8;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CLASS_11_11_10;
	DRIFTGL_EXPORT extern unsigned int GL_IMAGE_CLASS_10_10_10_2;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_128_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_96_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_64_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_48_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_32_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_24_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_16_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_8_BITS;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_S3TC_DXT1_RGB;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_S3TC_DXT1_RGBA;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_S3TC_DXT3_RGBA;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_S3TC_DXT5_RGBA;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_RGTC1_RED;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_RGTC2_RG;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_BPTC_UNORM;
	DRIFTGL_EXPORT extern unsigned int GL_VIEW_CLASS_BPTC_FLOAT;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM;
	DRIFTGL_EXPORT extern unsigned int GL_UNIFORM_BLOCK;
	DRIFTGL_EXPORT extern unsigned int GL_PROGRAM_INPUT;
	DRIFTGL_EXPORT extern unsigned int GL_PROGRAM_OUTPUT;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_VARIABLE;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_STORAGE_BLOCK;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_SUBROUTINE;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_CONTROL_SUBROUTINE;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_EVALUATION_SUBROUTINE;
	DRIFTGL_EXPORT extern unsigned int GL_GEOMETRY_SUBROUTINE;
	DRIFTGL_EXPORT extern unsigned int GL_FRAGMENT_SUBROUTINE;
	DRIFTGL_EXPORT extern unsigned int GL_COMPUTE_SUBROUTINE;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_SUBROUTINE_UNIFORM;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_CONTROL_SUBROUTINE_UNIFORM;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_EVALUATION_SUBROUTINE_UNIFORM;
	DRIFTGL_EXPORT extern unsigned int GL_GEOMETRY_SUBROUTINE_UNIFORM;
	DRIFTGL_EXPORT extern unsigned int GL_FRAGMENT_SUBROUTINE_UNIFORM;
	DRIFTGL_EXPORT extern unsigned int GL_COMPUTE_SUBROUTINE_UNIFORM;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_VARYING;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_RESOURCES;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_NAME_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_NUM_ACTIVE_VARIABLES;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_NUM_COMPATIBLE_SUBROUTINES;
	DRIFTGL_EXPORT extern unsigned int GL_NAME_LENGTH;
	DRIFTGL_EXPORT extern unsigned int GL_TYPE;
	DRIFTGL_EXPORT extern unsigned int GL_ARRAY_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_BLOCK_INDEX;
	DRIFTGL_EXPORT extern unsigned int GL_ARRAY_STRIDE;
	DRIFTGL_EXPORT extern unsigned int GL_MATRIX_STRIDE;
	DRIFTGL_EXPORT extern unsigned int GL_IS_ROW_MAJOR;
	DRIFTGL_EXPORT extern unsigned int GL_ATOMIC_COUNTER_BUFFER_INDEX;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_DATA_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_NUM_ACTIVE_VARIABLES;
	DRIFTGL_EXPORT extern unsigned int GL_ACTIVE_VARIABLES;
	DRIFTGL_EXPORT extern unsigned int GL_REFERENCED_BY_VERTEX_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_REFERENCED_BY_TESS_CONTROL_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_REFERENCED_BY_TESS_EVALUATION_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_REFERENCED_BY_GEOMETRY_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_REFERENCED_BY_FRAGMENT_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_REFERENCED_BY_COMPUTE_SHADER;
	DRIFTGL_EXPORT extern unsigned int GL_TOP_LEVEL_ARRAY_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_TOP_LEVEL_ARRAY_STRIDE;
	DRIFTGL_EXPORT extern unsigned int GL_LOCATION;
	DRIFTGL_EXPORT extern unsigned int GL_LOCATION_INDEX;
	DRIFTGL_EXPORT extern unsigned int GL_IS_PER_PATCH;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_STORAGE_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_STORAGE_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_STORAGE_BUFFER_START;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_STORAGE_BUFFER_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_SHADER_STORAGE_BLOCK_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_STORAGE_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_SHADER_OUTPUT_RESOURCES;
	DRIFTGL_EXPORT extern unsigned int GL_DEPTH_STENCIL_TEXTURE_MODE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BUFFER_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BUFFER_SIZE;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_VIEW_MIN_LEVEL;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_VIEW_NUM_LEVELS;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_VIEW_MIN_LAYER;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_VIEW_NUM_LAYERS;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_IMMUTABLE_LEVELS;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_ATTRIB_RELATIVE_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_BINDING_DIVISOR;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_BINDING_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_BINDING_STRIDE;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_ATTRIB_BINDINGS;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_BINDING_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_DISPLAY_LIST;
	DRIFTGL_EXPORT extern unsigned int GL_STACK_UNDERFLOW;
	DRIFTGL_EXPORT extern unsigned int GL_STACK_OVERFLOW;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_VERTEX_ATTRIB_STRIDE;
	DRIFTGL_EXPORT extern unsigned int GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_MAP_PERSISTENT_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_MAP_COHERENT_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_DYNAMIC_STORAGE_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_CLIENT_STORAGE_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_IMMUTABLE_STORAGE;
	DRIFTGL_EXPORT extern unsigned int GL_BUFFER_STORAGE_FLAGS;
	DRIFTGL_EXPORT extern unsigned int GL_CLEAR_TEXTURE;
	DRIFTGL_EXPORT extern unsigned int GL_LOCATION_COMPONENT;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_BUFFER_INDEX;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_BUFFER_BARRIER_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_RESULT_NO_WAIT;
	DRIFTGL_EXPORT extern unsigned int GL_MIRROR_CLAMP_TO_EDGE;
	DRIFTGL_EXPORT extern unsigned int GL_CONTEXT_LOST;
	DRIFTGL_EXPORT extern unsigned int GL_NEGATIVE_ONE_TO_ONE;
	DRIFTGL_EXPORT extern unsigned int GL_ZERO_TO_ONE;
	DRIFTGL_EXPORT extern unsigned int GL_CLIP_ORIGIN;
	DRIFTGL_EXPORT extern unsigned int GL_CLIP_DEPTH_MODE;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_WAIT_INVERTED;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_NO_WAIT_INVERTED;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_BY_REGION_WAIT_INVERTED;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_BY_REGION_NO_WAIT_INVERTED;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_CULL_DISTANCES;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_COMBINED_CLIP_AND_CULL_DISTANCES;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_TARGET;
	DRIFTGL_EXPORT extern unsigned int GL_QUERY_TARGET;
	DRIFTGL_EXPORT extern unsigned int GL_GUILTY_CONTEXT_RESET;
	DRIFTGL_EXPORT extern unsigned int GL_INNOCENT_CONTEXT_RESET;
	DRIFTGL_EXPORT extern unsigned int GL_UNKNOWN_CONTEXT_RESET;
	DRIFTGL_EXPORT extern unsigned int GL_RESET_NOTIFICATION_STRATEGY;
	DRIFTGL_EXPORT extern unsigned int GL_LOSE_CONTEXT_ON_RESET;
	DRIFTGL_EXPORT extern unsigned int GL_NO_RESET_NOTIFICATION;
	DRIFTGL_EXPORT extern unsigned int GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_CONTEXT_RELEASE_BEHAVIOR;
	DRIFTGL_EXPORT extern unsigned int GL_CONTEXT_RELEASE_BEHAVIOR_FLUSH;
	DRIFTGL_EXPORT extern unsigned int GL_SHADER_BINARY_FORMAT_SPIR_V;
	DRIFTGL_EXPORT extern unsigned int GL_SPIR_V_BINARY;
	DRIFTGL_EXPORT extern unsigned int GL_PARAMETER_BUFFER;
	DRIFTGL_EXPORT extern unsigned int GL_PARAMETER_BUFFER_BINDING;
	DRIFTGL_EXPORT extern unsigned int GL_CONTEXT_FLAG_NO_ERROR_BIT;
	DRIFTGL_EXPORT extern unsigned int GL_VERTICES_SUBMITTED;
	DRIFTGL_EXPORT extern unsigned int GL_PRIMITIVES_SUBMITTED;
	DRIFTGL_EXPORT extern unsigned int GL_VERTEX_SHADER_INVOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_CONTROL_SHADER_PATCHES;
	DRIFTGL_EXPORT extern unsigned int GL_TESS_EVALUATION_SHADER_INVOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_GEOMETRY_SHADER_PRIMITIVES_EMITTED;
	DRIFTGL_EXPORT extern unsigned int GL_FRAGMENT_SHADER_INVOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_COMPUTE_SHADER_INVOCATIONS;
	DRIFTGL_EXPORT extern unsigned int GL_CLIPPING_INPUT_PRIMITIVES;
	DRIFTGL_EXPORT extern unsigned int GL_CLIPPING_OUTPUT_PRIMITIVES;
	DRIFTGL_EXPORT extern unsigned int GL_POLYGON_OFFSET_CLAMP;
	DRIFTGL_EXPORT extern unsigned int GL_SPIR_V_EXTENSIONS;
	DRIFTGL_EXPORT extern unsigned int GL_NUM_SPIR_V_EXTENSIONS;
	DRIFTGL_EXPORT extern unsigned int GL_TEXTURE_MAX_ANISOTROPY;
	DRIFTGL_EXPORT extern unsigned int GL_MAX_TEXTURE_MAX_ANISOTROPY;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_OVERFLOW;
	DRIFTGL_EXPORT extern unsigned int GL_TRANSFORM_FEEDBACK_STREAM_OVERFLOW;
	
	DRIFTGL_EXPORT void glCullFace(GLenum mode);
	DRIFTGL_EXPORT void glFrontFace(GLenum mode);
	DRIFTGL_EXPORT void glHint(GLenum target, GLenum mode);
	DRIFTGL_EXPORT void glLineWidth(GLfloat width);
	DRIFTGL_EXPORT void glPointSize(GLfloat size);
	DRIFTGL_EXPORT void glPolygonMode(GLenum face, GLenum mode);
	DRIFTGL_EXPORT void glScissor(GLint x, GLint y, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glTexParameterf(GLenum target, GLenum pname, GLfloat param);
	DRIFTGL_EXPORT void glTexParameterfv(GLenum target, GLenum pname, GLfloat * params);
	DRIFTGL_EXPORT void glTexParameteri(GLenum target, GLenum pname, GLint param);
	DRIFTGL_EXPORT void glTexParameteriv(GLenum target, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glTexImage1D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void * pixels);
	DRIFTGL_EXPORT void glTexImage2D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void * pixels);
	DRIFTGL_EXPORT void glDrawBuffer(GLenum buf);
	DRIFTGL_EXPORT void glClear(GLbitfield mask);
	DRIFTGL_EXPORT void glClearColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
	DRIFTGL_EXPORT void glClearStencil(GLint s);
	DRIFTGL_EXPORT void glClearDepth(GLdouble depth);
	DRIFTGL_EXPORT void glStencilMask(GLuint mask);
	DRIFTGL_EXPORT void glColorMask(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha);
	DRIFTGL_EXPORT void glDepthMask(GLboolean flag);
	DRIFTGL_EXPORT void glDisable(GLenum cap);
	DRIFTGL_EXPORT void glEnable(GLenum cap);
	DRIFTGL_EXPORT void glFinish();
	DRIFTGL_EXPORT void glFlush();
	DRIFTGL_EXPORT void glBlendFunc(GLenum sfactor, GLenum dfactor);
	DRIFTGL_EXPORT void glLogicOp(GLenum opcode);
	DRIFTGL_EXPORT void glStencilFunc(GLenum func, GLint ref, GLuint mask);
	DRIFTGL_EXPORT void glStencilOp(GLenum fail, GLenum zfail, GLenum zpass);
	DRIFTGL_EXPORT void glDepthFunc(GLenum func);
	DRIFTGL_EXPORT void glPixelStoref(GLenum pname, GLfloat param);
	DRIFTGL_EXPORT void glPixelStorei(GLenum pname, GLint param);
	DRIFTGL_EXPORT void glReadBuffer(GLenum src);
	DRIFTGL_EXPORT void glReadPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, void * pixels);
	DRIFTGL_EXPORT void glGetBooleanv(GLenum pname, GLboolean * data);
	DRIFTGL_EXPORT void glGetDoublev(GLenum pname, GLdouble * data);
	DRIFTGL_EXPORT GLenum glGetError();
	DRIFTGL_EXPORT void glGetFloatv(GLenum pname, GLfloat * data);
	DRIFTGL_EXPORT void glGetIntegerv(GLenum pname, GLint * data);
	DRIFTGL_EXPORT GLubyte * glGetString(GLenum name);
	DRIFTGL_EXPORT void glGetTexImage(GLenum target, GLint level, GLenum format, GLenum type, void * pixels);
	DRIFTGL_EXPORT void glGetTexParameterfv(GLenum target, GLenum pname, GLfloat * params);
	DRIFTGL_EXPORT void glGetTexParameteriv(GLenum target, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetTexLevelParameterfv(GLenum target, GLint level, GLenum pname, GLfloat * params);
	DRIFTGL_EXPORT void glGetTexLevelParameteriv(GLenum target, GLint level, GLenum pname, GLint * params);
	DRIFTGL_EXPORT GLboolean glIsEnabled(GLenum cap);
	DRIFTGL_EXPORT void glDepthRange(GLdouble n, GLdouble f);
	DRIFTGL_EXPORT void glViewport(GLint x, GLint y, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glDrawArrays(GLenum mode, GLint first, GLsizei count);
	DRIFTGL_EXPORT void glDrawElements(GLenum mode, GLsizei count, GLenum type, const void * indices);
	DRIFTGL_EXPORT void glPolygonOffset(GLfloat factor, GLfloat units);
	DRIFTGL_EXPORT void glCopyTexImage1D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border);
	DRIFTGL_EXPORT void glCopyTexImage2D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border);
	DRIFTGL_EXPORT void glCopyTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width);
	DRIFTGL_EXPORT void glCopyTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void * pixels);
	DRIFTGL_EXPORT void glTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void * pixels);
	DRIFTGL_EXPORT void glBindTexture(GLenum target, GLuint texture);
	DRIFTGL_EXPORT void glDeleteTextures(GLsizei n, GLuint * textures);
	DRIFTGL_EXPORT void glGenTextures(GLsizei n, GLuint * textures);
	DRIFTGL_EXPORT GLboolean glIsTexture(GLuint texture);
	DRIFTGL_EXPORT void glDrawRangeElements(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void * indices);
	DRIFTGL_EXPORT void glTexImage3D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void * pixels);
	DRIFTGL_EXPORT void glTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void * pixels);
	DRIFTGL_EXPORT void glCopyTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glActiveTexture(GLenum texture);
	DRIFTGL_EXPORT void glSampleCoverage(GLfloat value, GLboolean invert);
	DRIFTGL_EXPORT void glCompressedTexImage3D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void * data);
	DRIFTGL_EXPORT void glCompressedTexImage2D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void * data);
	DRIFTGL_EXPORT void glCompressedTexImage1D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void * data);
	DRIFTGL_EXPORT void glCompressedTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void * data);
	DRIFTGL_EXPORT void glCompressedTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void * data);
	DRIFTGL_EXPORT void glCompressedTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void * data);
	DRIFTGL_EXPORT void glGetCompressedTexImage(GLenum target, GLint level, void * img);
	DRIFTGL_EXPORT void glBlendFuncSeparate(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha);
	DRIFTGL_EXPORT void glMultiDrawArrays(GLenum mode, GLint * first, GLsizei * count, GLsizei drawcount);
	DRIFTGL_EXPORT void glMultiDrawElements(GLenum mode, GLsizei * count, GLenum type, const void *const* indices, GLsizei drawcount);
	DRIFTGL_EXPORT void glPointParameterf(GLenum pname, GLfloat param);
	DRIFTGL_EXPORT void glPointParameterfv(GLenum pname, GLfloat * params);
	DRIFTGL_EXPORT void glPointParameteri(GLenum pname, GLint param);
	DRIFTGL_EXPORT void glPointParameteriv(GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glBlendColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
	DRIFTGL_EXPORT void glBlendEquation(GLenum mode);
	DRIFTGL_EXPORT void glGenQueries(GLsizei n, GLuint * ids);
	DRIFTGL_EXPORT void glDeleteQueries(GLsizei n, GLuint * ids);
	DRIFTGL_EXPORT GLboolean glIsQuery(GLuint id);
	DRIFTGL_EXPORT void glBeginQuery(GLenum target, GLuint id);
	DRIFTGL_EXPORT void glEndQuery(GLenum target);
	DRIFTGL_EXPORT void glGetQueryiv(GLenum target, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetQueryObjectiv(GLuint id, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetQueryObjectuiv(GLuint id, GLenum pname, GLuint * params);
	DRIFTGL_EXPORT void glBindBuffer(GLenum target, GLuint buffer);
	DRIFTGL_EXPORT void glDeleteBuffers(GLsizei n, GLuint * buffers);
	DRIFTGL_EXPORT void glGenBuffers(GLsizei n, GLuint * buffers);
	DRIFTGL_EXPORT GLboolean glIsBuffer(GLuint buffer);
	DRIFTGL_EXPORT void glBufferData(GLenum target, GLsizeiptr size, const void * data, GLenum usage);
	DRIFTGL_EXPORT void glBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, const void * data);
	DRIFTGL_EXPORT void glGetBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, void * data);
	DRIFTGL_EXPORT void * glMapBuffer(GLenum target, GLenum access);
	DRIFTGL_EXPORT GLboolean glUnmapBuffer(GLenum target);
	DRIFTGL_EXPORT void glGetBufferParameteriv(GLenum target, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetBufferPointerv(GLenum target, GLenum pname, void ** params);
	DRIFTGL_EXPORT void glBlendEquationSeparate(GLenum modeRGB, GLenum modeAlpha);
	DRIFTGL_EXPORT void glDrawBuffers(GLsizei n, GLenum * bufs);
	DRIFTGL_EXPORT void glStencilOpSeparate(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass);
	DRIFTGL_EXPORT void glStencilFuncSeparate(GLenum face, GLenum func, GLint ref, GLuint mask);
	DRIFTGL_EXPORT void glStencilMaskSeparate(GLenum face, GLuint mask);
	DRIFTGL_EXPORT void glAttachShader(GLuint program, GLuint shader);
	DRIFTGL_EXPORT void glBindAttribLocation(GLuint program, GLuint index, GLchar * name);
	DRIFTGL_EXPORT void glCompileShader(GLuint shader);
	DRIFTGL_EXPORT GLuint glCreateProgram();
	DRIFTGL_EXPORT GLuint glCreateShader(GLenum type);
	DRIFTGL_EXPORT void glDeleteProgram(GLuint program);
	DRIFTGL_EXPORT void glDeleteShader(GLuint shader);
	DRIFTGL_EXPORT void glDetachShader(GLuint program, GLuint shader);
	DRIFTGL_EXPORT void glDisableVertexAttribArray(GLuint index);
	DRIFTGL_EXPORT void glEnableVertexAttribArray(GLuint index);
	DRIFTGL_EXPORT void glGetActiveAttrib(GLuint program, GLuint index, GLsizei bufSize, GLsizei * length, GLint * size, GLenum * type, GLchar * name);
	DRIFTGL_EXPORT void glGetActiveUniform(GLuint program, GLuint index, GLsizei bufSize, GLsizei * length, GLint * size, GLenum * type, GLchar * name);
	DRIFTGL_EXPORT void glGetAttachedShaders(GLuint program, GLsizei maxCount, GLsizei * count, GLuint * shaders);
	DRIFTGL_EXPORT GLint glGetAttribLocation(GLuint program, GLchar * name);
	DRIFTGL_EXPORT void glGetProgramiv(GLuint program, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetProgramInfoLog(GLuint program, GLsizei bufSize, GLsizei * length, GLchar * infoLog);
	DRIFTGL_EXPORT void glGetShaderiv(GLuint shader, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetShaderInfoLog(GLuint shader, GLsizei bufSize, GLsizei * length, GLchar * infoLog);
	DRIFTGL_EXPORT void glGetShaderSource(GLuint shader, GLsizei bufSize, GLsizei * length, GLchar * source);
	DRIFTGL_EXPORT GLint glGetUniformLocation(GLuint program, GLchar * name);
	DRIFTGL_EXPORT void glGetUniformfv(GLuint program, GLint location, GLfloat * params);
	DRIFTGL_EXPORT void glGetUniformiv(GLuint program, GLint location, GLint * params);
	DRIFTGL_EXPORT void glGetVertexAttribdv(GLuint index, GLenum pname, GLdouble * params);
	DRIFTGL_EXPORT void glGetVertexAttribfv(GLuint index, GLenum pname, GLfloat * params);
	DRIFTGL_EXPORT void glGetVertexAttribiv(GLuint index, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetVertexAttribPointerv(GLuint index, GLenum pname, void ** pointer);
	DRIFTGL_EXPORT GLboolean glIsProgram(GLuint program);
	DRIFTGL_EXPORT GLboolean glIsShader(GLuint shader);
	DRIFTGL_EXPORT void glLinkProgram(GLuint program);
	DRIFTGL_EXPORT void glShaderSource(GLuint shader, GLsizei count, GLchar *const* string, GLint * length);
	DRIFTGL_EXPORT void glUseProgram(GLuint program);
	DRIFTGL_EXPORT void glUniform1f(GLint location, GLfloat v0);
	DRIFTGL_EXPORT void glUniform2f(GLint location, GLfloat v0, GLfloat v1);
	DRIFTGL_EXPORT void glUniform3f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2);
	DRIFTGL_EXPORT void glUniform4f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3);
	DRIFTGL_EXPORT void glUniform1i(GLint location, GLint v0);
	DRIFTGL_EXPORT void glUniform2i(GLint location, GLint v0, GLint v1);
	DRIFTGL_EXPORT void glUniform3i(GLint location, GLint v0, GLint v1, GLint v2);
	DRIFTGL_EXPORT void glUniform4i(GLint location, GLint v0, GLint v1, GLint v2, GLint v3);
	DRIFTGL_EXPORT void glUniform1fv(GLint location, GLsizei count, GLfloat * value);
	DRIFTGL_EXPORT void glUniform2fv(GLint location, GLsizei count, GLfloat * value);
	DRIFTGL_EXPORT void glUniform3fv(GLint location, GLsizei count, GLfloat * value);
	DRIFTGL_EXPORT void glUniform4fv(GLint location, GLsizei count, GLfloat * value);
	DRIFTGL_EXPORT void glUniform1iv(GLint location, GLsizei count, GLint * value);
	DRIFTGL_EXPORT void glUniform2iv(GLint location, GLsizei count, GLint * value);
	DRIFTGL_EXPORT void glUniform3iv(GLint location, GLsizei count, GLint * value);
	DRIFTGL_EXPORT void glUniform4iv(GLint location, GLsizei count, GLint * value);
	DRIFTGL_EXPORT void glUniformMatrix2fv(GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glUniformMatrix3fv(GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glUniformMatrix4fv(GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glValidateProgram(GLuint program);
	DRIFTGL_EXPORT void glVertexAttrib1d(GLuint index, GLdouble x);
	DRIFTGL_EXPORT void glVertexAttrib1dv(GLuint index, GLdouble * v);
	DRIFTGL_EXPORT void glVertexAttrib1f(GLuint index, GLfloat x);
	DRIFTGL_EXPORT void glVertexAttrib1fv(GLuint index, GLfloat * v);
	DRIFTGL_EXPORT void glVertexAttrib1s(GLuint index, GLshort x);
	DRIFTGL_EXPORT void glVertexAttrib1sv(GLuint index, GLshort * v);
	DRIFTGL_EXPORT void glVertexAttrib2d(GLuint index, GLdouble x, GLdouble y);
	DRIFTGL_EXPORT void glVertexAttrib2dv(GLuint index, GLdouble * v);
	DRIFTGL_EXPORT void glVertexAttrib2f(GLuint index, GLfloat x, GLfloat y);
	DRIFTGL_EXPORT void glVertexAttrib2fv(GLuint index, GLfloat * v);
	DRIFTGL_EXPORT void glVertexAttrib2s(GLuint index, GLshort x, GLshort y);
	DRIFTGL_EXPORT void glVertexAttrib2sv(GLuint index, GLshort * v);
	DRIFTGL_EXPORT void glVertexAttrib3d(GLuint index, GLdouble x, GLdouble y, GLdouble z);
	DRIFTGL_EXPORT void glVertexAttrib3dv(GLuint index, GLdouble * v);
	DRIFTGL_EXPORT void glVertexAttrib3f(GLuint index, GLfloat x, GLfloat y, GLfloat z);
	DRIFTGL_EXPORT void glVertexAttrib3fv(GLuint index, GLfloat * v);
	DRIFTGL_EXPORT void glVertexAttrib3s(GLuint index, GLshort x, GLshort y, GLshort z);
	DRIFTGL_EXPORT void glVertexAttrib3sv(GLuint index, GLshort * v);
	DRIFTGL_EXPORT void glVertexAttrib4Nbv(GLuint index, GLbyte * v);
	DRIFTGL_EXPORT void glVertexAttrib4Niv(GLuint index, GLint * v);
	DRIFTGL_EXPORT void glVertexAttrib4Nsv(GLuint index, GLshort * v);
	DRIFTGL_EXPORT void glVertexAttrib4Nub(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w);
	DRIFTGL_EXPORT void glVertexAttrib4Nubv(GLuint index, GLubyte * v);
	DRIFTGL_EXPORT void glVertexAttrib4Nuiv(GLuint index, GLuint * v);
	DRIFTGL_EXPORT void glVertexAttrib4Nusv(GLuint index, GLushort * v);
	DRIFTGL_EXPORT void glVertexAttrib4bv(GLuint index, GLbyte * v);
	DRIFTGL_EXPORT void glVertexAttrib4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
	DRIFTGL_EXPORT void glVertexAttrib4dv(GLuint index, GLdouble * v);
	DRIFTGL_EXPORT void glVertexAttrib4f(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
	DRIFTGL_EXPORT void glVertexAttrib4fv(GLuint index, GLfloat * v);
	DRIFTGL_EXPORT void glVertexAttrib4iv(GLuint index, GLint * v);
	DRIFTGL_EXPORT void glVertexAttrib4s(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w);
	DRIFTGL_EXPORT void glVertexAttrib4sv(GLuint index, GLshort * v);
	DRIFTGL_EXPORT void glVertexAttrib4ubv(GLuint index, GLubyte * v);
	DRIFTGL_EXPORT void glVertexAttrib4uiv(GLuint index, GLuint * v);
	DRIFTGL_EXPORT void glVertexAttrib4usv(GLuint index, GLushort * v);
	DRIFTGL_EXPORT void glVertexAttribPointer(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void * pointer);
	DRIFTGL_EXPORT void glUniformMatrix2x3fv(GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glUniformMatrix3x2fv(GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glUniformMatrix2x4fv(GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glUniformMatrix4x2fv(GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glUniformMatrix3x4fv(GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glUniformMatrix4x3fv(GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glColorMaski(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a);
	DRIFTGL_EXPORT void glGetBooleani_v(GLenum target, GLuint index, GLboolean * data);
	DRIFTGL_EXPORT void glGetIntegeri_v(GLenum target, GLuint index, GLint * data);
	DRIFTGL_EXPORT void glEnablei(GLenum target, GLuint index);
	DRIFTGL_EXPORT void glDisablei(GLenum target, GLuint index);
	DRIFTGL_EXPORT GLboolean glIsEnabledi(GLenum target, GLuint index);
	DRIFTGL_EXPORT void glBeginTransformFeedback(GLenum primitiveMode);
	DRIFTGL_EXPORT void glEndTransformFeedback();
	DRIFTGL_EXPORT void glBindBufferRange(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size);
	DRIFTGL_EXPORT void glBindBufferBase(GLenum target, GLuint index, GLuint buffer);
	DRIFTGL_EXPORT void glTransformFeedbackVaryings(GLuint program, GLsizei count, GLchar *const* varyings, GLenum bufferMode);
	DRIFTGL_EXPORT void glGetTransformFeedbackVarying(GLuint program, GLuint index, GLsizei bufSize, GLsizei * length, GLsizei * size, GLenum * type, GLchar * name);
	DRIFTGL_EXPORT void glClampColor(GLenum target, GLenum clamp);
	DRIFTGL_EXPORT void glBeginConditionalRender(GLuint id, GLenum mode);
	DRIFTGL_EXPORT void glEndConditionalRender();
	DRIFTGL_EXPORT void glVertexAttribIPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void * pointer);
	DRIFTGL_EXPORT void glGetVertexAttribIiv(GLuint index, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetVertexAttribIuiv(GLuint index, GLenum pname, GLuint * params);
	DRIFTGL_EXPORT void glVertexAttribI1i(GLuint index, GLint x);
	DRIFTGL_EXPORT void glVertexAttribI2i(GLuint index, GLint x, GLint y);
	DRIFTGL_EXPORT void glVertexAttribI3i(GLuint index, GLint x, GLint y, GLint z);
	DRIFTGL_EXPORT void glVertexAttribI4i(GLuint index, GLint x, GLint y, GLint z, GLint w);
	DRIFTGL_EXPORT void glVertexAttribI1ui(GLuint index, GLuint x);
	DRIFTGL_EXPORT void glVertexAttribI2ui(GLuint index, GLuint x, GLuint y);
	DRIFTGL_EXPORT void glVertexAttribI3ui(GLuint index, GLuint x, GLuint y, GLuint z);
	DRIFTGL_EXPORT void glVertexAttribI4ui(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w);
	DRIFTGL_EXPORT void glVertexAttribI1iv(GLuint index, GLint * v);
	DRIFTGL_EXPORT void glVertexAttribI2iv(GLuint index, GLint * v);
	DRIFTGL_EXPORT void glVertexAttribI3iv(GLuint index, GLint * v);
	DRIFTGL_EXPORT void glVertexAttribI4iv(GLuint index, GLint * v);
	DRIFTGL_EXPORT void glVertexAttribI1uiv(GLuint index, GLuint * v);
	DRIFTGL_EXPORT void glVertexAttribI2uiv(GLuint index, GLuint * v);
	DRIFTGL_EXPORT void glVertexAttribI3uiv(GLuint index, GLuint * v);
	DRIFTGL_EXPORT void glVertexAttribI4uiv(GLuint index, GLuint * v);
	DRIFTGL_EXPORT void glVertexAttribI4bv(GLuint index, GLbyte * v);
	DRIFTGL_EXPORT void glVertexAttribI4sv(GLuint index, GLshort * v);
	DRIFTGL_EXPORT void glVertexAttribI4ubv(GLuint index, GLubyte * v);
	DRIFTGL_EXPORT void glVertexAttribI4usv(GLuint index, GLushort * v);
	DRIFTGL_EXPORT void glGetUniformuiv(GLuint program, GLint location, GLuint * params);
	DRIFTGL_EXPORT void glBindFragDataLocation(GLuint program, GLuint color, GLchar * name);
	DRIFTGL_EXPORT GLint glGetFragDataLocation(GLuint program, GLchar * name);
	DRIFTGL_EXPORT void glUniform1ui(GLint location, GLuint v0);
	DRIFTGL_EXPORT void glUniform2ui(GLint location, GLuint v0, GLuint v1);
	DRIFTGL_EXPORT void glUniform3ui(GLint location, GLuint v0, GLuint v1, GLuint v2);
	DRIFTGL_EXPORT void glUniform4ui(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3);
	DRIFTGL_EXPORT void glUniform1uiv(GLint location, GLsizei count, GLuint * value);
	DRIFTGL_EXPORT void glUniform2uiv(GLint location, GLsizei count, GLuint * value);
	DRIFTGL_EXPORT void glUniform3uiv(GLint location, GLsizei count, GLuint * value);
	DRIFTGL_EXPORT void glUniform4uiv(GLint location, GLsizei count, GLuint * value);
	DRIFTGL_EXPORT void glTexParameterIiv(GLenum target, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glTexParameterIuiv(GLenum target, GLenum pname, GLuint * params);
	DRIFTGL_EXPORT void glGetTexParameterIiv(GLenum target, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetTexParameterIuiv(GLenum target, GLenum pname, GLuint * params);
	DRIFTGL_EXPORT void glClearBufferiv(GLenum buffer, GLint drawbuffer, GLint * value);
	DRIFTGL_EXPORT void glClearBufferuiv(GLenum buffer, GLint drawbuffer, GLuint * value);
	DRIFTGL_EXPORT void glClearBufferfv(GLenum buffer, GLint drawbuffer, GLfloat * value);
	DRIFTGL_EXPORT void glClearBufferfi(GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil);
	DRIFTGL_EXPORT GLubyte * glGetStringi(GLenum name, GLuint index);
	DRIFTGL_EXPORT GLboolean glIsRenderbuffer(GLuint renderbuffer);
	DRIFTGL_EXPORT void glBindRenderbuffer(GLenum target, GLuint renderbuffer);
	DRIFTGL_EXPORT void glDeleteRenderbuffers(GLsizei n, GLuint * renderbuffers);
	DRIFTGL_EXPORT void glGenRenderbuffers(GLsizei n, GLuint * renderbuffers);
	DRIFTGL_EXPORT void glRenderbufferStorage(GLenum target, GLenum internalformat, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glGetRenderbufferParameteriv(GLenum target, GLenum pname, GLint * params);
	DRIFTGL_EXPORT GLboolean glIsFramebuffer(GLuint framebuffer);
	DRIFTGL_EXPORT void glBindFramebuffer(GLenum target, GLuint framebuffer);
	DRIFTGL_EXPORT void glDeleteFramebuffers(GLsizei n, GLuint * framebuffers);
	DRIFTGL_EXPORT void glGenFramebuffers(GLsizei n, GLuint * framebuffers);
	DRIFTGL_EXPORT GLenum glCheckFramebufferStatus(GLenum target);
	DRIFTGL_EXPORT void glFramebufferTexture1D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
	DRIFTGL_EXPORT void glFramebufferTexture2D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
	DRIFTGL_EXPORT void glFramebufferTexture3D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset);
	DRIFTGL_EXPORT void glFramebufferRenderbuffer(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
	DRIFTGL_EXPORT void glGetFramebufferAttachmentParameteriv(GLenum target, GLenum attachment, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGenerateMipmap(GLenum target);
	DRIFTGL_EXPORT void glBlitFramebuffer(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter);
	DRIFTGL_EXPORT void glRenderbufferStorageMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glFramebufferTextureLayer(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer);
	DRIFTGL_EXPORT void * glMapBufferRange(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access);
	DRIFTGL_EXPORT void glFlushMappedBufferRange(GLenum target, GLintptr offset, GLsizeiptr length);
	DRIFTGL_EXPORT void glBindVertexArray(GLuint array);
	DRIFTGL_EXPORT void glDeleteVertexArrays(GLsizei n, GLuint * arrays);
	DRIFTGL_EXPORT void glGenVertexArrays(GLsizei n, GLuint * arrays);
	DRIFTGL_EXPORT GLboolean glIsVertexArray(GLuint array);
	DRIFTGL_EXPORT void glDrawArraysInstanced(GLenum mode, GLint first, GLsizei count, GLsizei instancecount);
	DRIFTGL_EXPORT void glDrawElementsInstanced(GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount);
	DRIFTGL_EXPORT void glTexBuffer(GLenum target, GLenum internalformat, GLuint buffer);
	DRIFTGL_EXPORT void glPrimitiveRestartIndex(GLuint index);
	DRIFTGL_EXPORT void glCopyBufferSubData(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size);
	DRIFTGL_EXPORT void glGetUniformIndices(GLuint program, GLsizei uniformCount, GLchar *const* uniformNames, GLuint * uniformIndices);
	DRIFTGL_EXPORT void glGetActiveUniformsiv(GLuint program, GLsizei uniformCount, GLuint * uniformIndices, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetActiveUniformName(GLuint program, GLuint uniformIndex, GLsizei bufSize, GLsizei * length, GLchar * uniformName);
	DRIFTGL_EXPORT GLuint glGetUniformBlockIndex(GLuint program, GLchar * uniformBlockName);
	DRIFTGL_EXPORT void glGetActiveUniformBlockiv(GLuint program, GLuint uniformBlockIndex, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetActiveUniformBlockName(GLuint program, GLuint uniformBlockIndex, GLsizei bufSize, GLsizei * length, GLchar * uniformBlockName);
	DRIFTGL_EXPORT void glUniformBlockBinding(GLuint program, GLuint uniformBlockIndex, GLuint uniformBlockBinding);
	DRIFTGL_EXPORT void glDrawElementsBaseVertex(GLenum mode, GLsizei count, GLenum type, const void * indices, GLint basevertex);
	DRIFTGL_EXPORT void glDrawRangeElementsBaseVertex(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void * indices, GLint basevertex);
	DRIFTGL_EXPORT void glDrawElementsInstancedBaseVertex(GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount, GLint basevertex);
	DRIFTGL_EXPORT void glMultiDrawElementsBaseVertex(GLenum mode, GLsizei * count, GLenum type, const void *const* indices, GLsizei drawcount, GLint * basevertex);
	DRIFTGL_EXPORT void glProvokingVertex(GLenum mode);
	DRIFTGL_EXPORT GLsync glFenceSync(GLenum condition, GLbitfield flags);
	DRIFTGL_EXPORT GLboolean glIsSync(GLsync sync);
	DRIFTGL_EXPORT void glDeleteSync(GLsync sync);
	DRIFTGL_EXPORT GLenum glClientWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout);
	DRIFTGL_EXPORT void glWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout);
	DRIFTGL_EXPORT void glGetInteger64v(GLenum pname, GLint64 * data);
	DRIFTGL_EXPORT void glGetSynciv(GLsync sync, GLenum pname, GLsizei bufSize, GLsizei * length, GLint * values);
	DRIFTGL_EXPORT void glGetInteger64i_v(GLenum target, GLuint index, GLint64 * data);
	DRIFTGL_EXPORT void glGetBufferParameteri64v(GLenum target, GLenum pname, GLint64 * params);
	DRIFTGL_EXPORT void glFramebufferTexture(GLenum target, GLenum attachment, GLuint texture, GLint level);
	DRIFTGL_EXPORT void glTexImage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations);
	DRIFTGL_EXPORT void glTexImage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations);
	DRIFTGL_EXPORT void glGetMultisamplefv(GLenum pname, GLuint index, GLfloat * val);
	DRIFTGL_EXPORT void glSampleMaski(GLuint maskNumber, GLbitfield mask);
	DRIFTGL_EXPORT void glBindFragDataLocationIndexed(GLuint program, GLuint colorNumber, GLuint index, GLchar * name);
	DRIFTGL_EXPORT GLint glGetFragDataIndex(GLuint program, GLchar * name);
	DRIFTGL_EXPORT void glGenSamplers(GLsizei count, GLuint * samplers);
	DRIFTGL_EXPORT void glDeleteSamplers(GLsizei count, GLuint * samplers);
	DRIFTGL_EXPORT GLboolean glIsSampler(GLuint sampler);
	DRIFTGL_EXPORT void glBindSampler(GLuint unit, GLuint sampler);
	DRIFTGL_EXPORT void glSamplerParameteri(GLuint sampler, GLenum pname, GLint param);
	DRIFTGL_EXPORT void glSamplerParameteriv(GLuint sampler, GLenum pname, GLint * param);
	DRIFTGL_EXPORT void glSamplerParameterf(GLuint sampler, GLenum pname, GLfloat param);
	DRIFTGL_EXPORT void glSamplerParameterfv(GLuint sampler, GLenum pname, GLfloat * param);
	DRIFTGL_EXPORT void glSamplerParameterIiv(GLuint sampler, GLenum pname, GLint * param);
	DRIFTGL_EXPORT void glSamplerParameterIuiv(GLuint sampler, GLenum pname, GLuint * param);
	DRIFTGL_EXPORT void glGetSamplerParameteriv(GLuint sampler, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetSamplerParameterIiv(GLuint sampler, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetSamplerParameterfv(GLuint sampler, GLenum pname, GLfloat * params);
	DRIFTGL_EXPORT void glGetSamplerParameterIuiv(GLuint sampler, GLenum pname, GLuint * params);
	DRIFTGL_EXPORT void glQueryCounter(GLuint id, GLenum target);
	DRIFTGL_EXPORT void glGetQueryObjecti64v(GLuint id, GLenum pname, GLint64 * params);
	DRIFTGL_EXPORT void glGetQueryObjectui64v(GLuint id, GLenum pname, GLuint64 * params);
	DRIFTGL_EXPORT void glVertexAttribDivisor(GLuint index, GLuint divisor);
	DRIFTGL_EXPORT void glVertexAttribP1ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
	DRIFTGL_EXPORT void glVertexAttribP1uiv(GLuint index, GLenum type, GLboolean normalized, GLuint * value);
	DRIFTGL_EXPORT void glVertexAttribP2ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
	DRIFTGL_EXPORT void glVertexAttribP2uiv(GLuint index, GLenum type, GLboolean normalized, GLuint * value);
	DRIFTGL_EXPORT void glVertexAttribP3ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
	DRIFTGL_EXPORT void glVertexAttribP3uiv(GLuint index, GLenum type, GLboolean normalized, GLuint * value);
	DRIFTGL_EXPORT void glVertexAttribP4ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
	DRIFTGL_EXPORT void glVertexAttribP4uiv(GLuint index, GLenum type, GLboolean normalized, GLuint * value);
	DRIFTGL_EXPORT void glVertexP2ui(GLenum type, GLuint value);
	DRIFTGL_EXPORT void glVertexP2uiv(GLenum type, GLuint * value);
	DRIFTGL_EXPORT void glVertexP3ui(GLenum type, GLuint value);
	DRIFTGL_EXPORT void glVertexP3uiv(GLenum type, GLuint * value);
	DRIFTGL_EXPORT void glVertexP4ui(GLenum type, GLuint value);
	DRIFTGL_EXPORT void glVertexP4uiv(GLenum type, GLuint * value);
	DRIFTGL_EXPORT void glTexCoordP1ui(GLenum type, GLuint coords);
	DRIFTGL_EXPORT void glTexCoordP1uiv(GLenum type, GLuint * coords);
	DRIFTGL_EXPORT void glTexCoordP2ui(GLenum type, GLuint coords);
	DRIFTGL_EXPORT void glTexCoordP2uiv(GLenum type, GLuint * coords);
	DRIFTGL_EXPORT void glTexCoordP3ui(GLenum type, GLuint coords);
	DRIFTGL_EXPORT void glTexCoordP3uiv(GLenum type, GLuint * coords);
	DRIFTGL_EXPORT void glTexCoordP4ui(GLenum type, GLuint coords);
	DRIFTGL_EXPORT void glTexCoordP4uiv(GLenum type, GLuint * coords);
	DRIFTGL_EXPORT void glMultiTexCoordP1ui(GLenum texture, GLenum type, GLuint coords);
	DRIFTGL_EXPORT void glMultiTexCoordP1uiv(GLenum texture, GLenum type, GLuint * coords);
	DRIFTGL_EXPORT void glMultiTexCoordP2ui(GLenum texture, GLenum type, GLuint coords);
	DRIFTGL_EXPORT void glMultiTexCoordP2uiv(GLenum texture, GLenum type, GLuint * coords);
	DRIFTGL_EXPORT void glMultiTexCoordP3ui(GLenum texture, GLenum type, GLuint coords);
	DRIFTGL_EXPORT void glMultiTexCoordP3uiv(GLenum texture, GLenum type, GLuint * coords);
	DRIFTGL_EXPORT void glMultiTexCoordP4ui(GLenum texture, GLenum type, GLuint coords);
	DRIFTGL_EXPORT void glMultiTexCoordP4uiv(GLenum texture, GLenum type, GLuint * coords);
	DRIFTGL_EXPORT void glNormalP3ui(GLenum type, GLuint coords);
	DRIFTGL_EXPORT void glNormalP3uiv(GLenum type, GLuint * coords);
	DRIFTGL_EXPORT void glColorP3ui(GLenum type, GLuint color);
	DRIFTGL_EXPORT void glColorP3uiv(GLenum type, GLuint * color);
	DRIFTGL_EXPORT void glColorP4ui(GLenum type, GLuint color);
	DRIFTGL_EXPORT void glColorP4uiv(GLenum type, GLuint * color);
	DRIFTGL_EXPORT void glSecondaryColorP3ui(GLenum type, GLuint color);
	DRIFTGL_EXPORT void glSecondaryColorP3uiv(GLenum type, GLuint * color);
	DRIFTGL_EXPORT void glMinSampleShading(GLfloat value);
	DRIFTGL_EXPORT void glBlendEquationi(GLuint buf, GLenum mode);
	DRIFTGL_EXPORT void glBlendEquationSeparatei(GLuint buf, GLenum modeRGB, GLenum modeAlpha);
	DRIFTGL_EXPORT void glBlendFunci(GLuint buf, GLenum src, GLenum dst);
	DRIFTGL_EXPORT void glBlendFuncSeparatei(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha);
	DRIFTGL_EXPORT void glDrawArraysIndirect(GLenum mode, const void * indirect);
	DRIFTGL_EXPORT void glDrawElementsIndirect(GLenum mode, GLenum type, const void * indirect);
	DRIFTGL_EXPORT void glUniform1d(GLint location, GLdouble x);
	DRIFTGL_EXPORT void glUniform2d(GLint location, GLdouble x, GLdouble y);
	DRIFTGL_EXPORT void glUniform3d(GLint location, GLdouble x, GLdouble y, GLdouble z);
	DRIFTGL_EXPORT void glUniform4d(GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
	DRIFTGL_EXPORT void glUniform1dv(GLint location, GLsizei count, GLdouble * value);
	DRIFTGL_EXPORT void glUniform2dv(GLint location, GLsizei count, GLdouble * value);
	DRIFTGL_EXPORT void glUniform3dv(GLint location, GLsizei count, GLdouble * value);
	DRIFTGL_EXPORT void glUniform4dv(GLint location, GLsizei count, GLdouble * value);
	DRIFTGL_EXPORT void glUniformMatrix2dv(GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glUniformMatrix3dv(GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glUniformMatrix4dv(GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glUniformMatrix2x3dv(GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glUniformMatrix2x4dv(GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glUniformMatrix3x2dv(GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glUniformMatrix3x4dv(GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glUniformMatrix4x2dv(GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glUniformMatrix4x3dv(GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glGetUniformdv(GLuint program, GLint location, GLdouble * params);
	DRIFTGL_EXPORT GLint glGetSubroutineUniformLocation(GLuint program, GLenum shadertype, GLchar * name);
	DRIFTGL_EXPORT GLuint glGetSubroutineIndex(GLuint program, GLenum shadertype, GLchar * name);
	DRIFTGL_EXPORT void glGetActiveSubroutineUniformiv(GLuint program, GLenum shadertype, GLuint index, GLenum pname, GLint * values);
	DRIFTGL_EXPORT void glGetActiveSubroutineUniformName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufsize, GLsizei * length, GLchar * name);
	DRIFTGL_EXPORT void glGetActiveSubroutineName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufsize, GLsizei * length, GLchar * name);
	DRIFTGL_EXPORT void glUniformSubroutinesuiv(GLenum shadertype, GLsizei count, GLuint * indices);
	DRIFTGL_EXPORT void glGetUniformSubroutineuiv(GLenum shadertype, GLint location, GLuint * params);
	DRIFTGL_EXPORT void glGetProgramStageiv(GLuint program, GLenum shadertype, GLenum pname, GLint * values);
	DRIFTGL_EXPORT void glPatchParameteri(GLenum pname, GLint value);
	DRIFTGL_EXPORT void glPatchParameterfv(GLenum pname, GLfloat * values);
	DRIFTGL_EXPORT void glBindTransformFeedback(GLenum target, GLuint id);
	DRIFTGL_EXPORT void glDeleteTransformFeedbacks(GLsizei n, GLuint * ids);
	DRIFTGL_EXPORT void glGenTransformFeedbacks(GLsizei n, GLuint * ids);
	DRIFTGL_EXPORT GLboolean glIsTransformFeedback(GLuint id);
	DRIFTGL_EXPORT void glPauseTransformFeedback();
	DRIFTGL_EXPORT void glResumeTransformFeedback();
	DRIFTGL_EXPORT void glDrawTransformFeedback(GLenum mode, GLuint id);
	DRIFTGL_EXPORT void glDrawTransformFeedbackStream(GLenum mode, GLuint id, GLuint stream);
	DRIFTGL_EXPORT void glBeginQueryIndexed(GLenum target, GLuint index, GLuint id);
	DRIFTGL_EXPORT void glEndQueryIndexed(GLenum target, GLuint index);
	DRIFTGL_EXPORT void glGetQueryIndexediv(GLenum target, GLuint index, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glReleaseShaderCompiler();
	DRIFTGL_EXPORT void glShaderBinary(GLsizei count, GLuint * shaders, GLenum binaryformat, const void * binary, GLsizei length);
	DRIFTGL_EXPORT void glGetShaderPrecisionFormat(GLenum shadertype, GLenum precisiontype, GLint * range, GLint * precision);
	DRIFTGL_EXPORT void glDepthRangef(GLfloat n, GLfloat f);
	DRIFTGL_EXPORT void glClearDepthf(GLfloat d);
	DRIFTGL_EXPORT void glGetProgramBinary(GLuint program, GLsizei bufSize, GLsizei * length, GLenum * binaryFormat, void * binary);
	DRIFTGL_EXPORT void glProgramBinary(GLuint program, GLenum binaryFormat, const void * binary, GLsizei length);
	DRIFTGL_EXPORT void glProgramParameteri(GLuint program, GLenum pname, GLint value);
	DRIFTGL_EXPORT void glUseProgramStages(GLuint pipeline, GLbitfield stages, GLuint program);
	DRIFTGL_EXPORT void glActiveShaderProgram(GLuint pipeline, GLuint program);
	DRIFTGL_EXPORT GLuint glCreateShaderProgramv(GLenum type, GLsizei count, GLchar *const* strings);
	DRIFTGL_EXPORT void glBindProgramPipeline(GLuint pipeline);
	DRIFTGL_EXPORT void glDeleteProgramPipelines(GLsizei n, GLuint * pipelines);
	DRIFTGL_EXPORT void glGenProgramPipelines(GLsizei n, GLuint * pipelines);
	DRIFTGL_EXPORT GLboolean glIsProgramPipeline(GLuint pipeline);
	DRIFTGL_EXPORT void glGetProgramPipelineiv(GLuint pipeline, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glProgramUniform1i(GLuint program, GLint location, GLint v0);
	DRIFTGL_EXPORT void glProgramUniform1iv(GLuint program, GLint location, GLsizei count, GLint * value);
	DRIFTGL_EXPORT void glProgramUniform1f(GLuint program, GLint location, GLfloat v0);
	DRIFTGL_EXPORT void glProgramUniform1fv(GLuint program, GLint location, GLsizei count, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniform1d(GLuint program, GLint location, GLdouble v0);
	DRIFTGL_EXPORT void glProgramUniform1dv(GLuint program, GLint location, GLsizei count, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniform1ui(GLuint program, GLint location, GLuint v0);
	DRIFTGL_EXPORT void glProgramUniform1uiv(GLuint program, GLint location, GLsizei count, GLuint * value);
	DRIFTGL_EXPORT void glProgramUniform2i(GLuint program, GLint location, GLint v0, GLint v1);
	DRIFTGL_EXPORT void glProgramUniform2iv(GLuint program, GLint location, GLsizei count, GLint * value);
	DRIFTGL_EXPORT void glProgramUniform2f(GLuint program, GLint location, GLfloat v0, GLfloat v1);
	DRIFTGL_EXPORT void glProgramUniform2fv(GLuint program, GLint location, GLsizei count, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniform2d(GLuint program, GLint location, GLdouble v0, GLdouble v1);
	DRIFTGL_EXPORT void glProgramUniform2dv(GLuint program, GLint location, GLsizei count, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniform2ui(GLuint program, GLint location, GLuint v0, GLuint v1);
	DRIFTGL_EXPORT void glProgramUniform2uiv(GLuint program, GLint location, GLsizei count, GLuint * value);
	DRIFTGL_EXPORT void glProgramUniform3i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2);
	DRIFTGL_EXPORT void glProgramUniform3iv(GLuint program, GLint location, GLsizei count, GLint * value);
	DRIFTGL_EXPORT void glProgramUniform3f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2);
	DRIFTGL_EXPORT void glProgramUniform3fv(GLuint program, GLint location, GLsizei count, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniform3d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2);
	DRIFTGL_EXPORT void glProgramUniform3dv(GLuint program, GLint location, GLsizei count, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniform3ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2);
	DRIFTGL_EXPORT void glProgramUniform3uiv(GLuint program, GLint location, GLsizei count, GLuint * value);
	DRIFTGL_EXPORT void glProgramUniform4i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3);
	DRIFTGL_EXPORT void glProgramUniform4iv(GLuint program, GLint location, GLsizei count, GLint * value);
	DRIFTGL_EXPORT void glProgramUniform4f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3);
	DRIFTGL_EXPORT void glProgramUniform4fv(GLuint program, GLint location, GLsizei count, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniform4d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2, GLdouble v3);
	DRIFTGL_EXPORT void glProgramUniform4dv(GLuint program, GLint location, GLsizei count, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniform4ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3);
	DRIFTGL_EXPORT void glProgramUniform4uiv(GLuint program, GLint location, GLsizei count, GLuint * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix2x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix3x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix2x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix4x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix3x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix4x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLfloat * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix2x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix3x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix2x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix4x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix3x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glProgramUniformMatrix4x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, GLdouble * value);
	DRIFTGL_EXPORT void glValidateProgramPipeline(GLuint pipeline);
	DRIFTGL_EXPORT void glGetProgramPipelineInfoLog(GLuint pipeline, GLsizei bufSize, GLsizei * length, GLchar * infoLog);
	DRIFTGL_EXPORT void glVertexAttribL1d(GLuint index, GLdouble x);
	DRIFTGL_EXPORT void glVertexAttribL2d(GLuint index, GLdouble x, GLdouble y);
	DRIFTGL_EXPORT void glVertexAttribL3d(GLuint index, GLdouble x, GLdouble y, GLdouble z);
	DRIFTGL_EXPORT void glVertexAttribL4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
	DRIFTGL_EXPORT void glVertexAttribL1dv(GLuint index, GLdouble * v);
	DRIFTGL_EXPORT void glVertexAttribL2dv(GLuint index, GLdouble * v);
	DRIFTGL_EXPORT void glVertexAttribL3dv(GLuint index, GLdouble * v);
	DRIFTGL_EXPORT void glVertexAttribL4dv(GLuint index, GLdouble * v);
	DRIFTGL_EXPORT void glVertexAttribLPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void * pointer);
	DRIFTGL_EXPORT void glGetVertexAttribLdv(GLuint index, GLenum pname, GLdouble * params);
	DRIFTGL_EXPORT void glViewportArrayv(GLuint first, GLsizei count, GLfloat * v);
	DRIFTGL_EXPORT void glViewportIndexedf(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h);
	DRIFTGL_EXPORT void glViewportIndexedfv(GLuint index, GLfloat * v);
	DRIFTGL_EXPORT void glScissorArrayv(GLuint first, GLsizei count, GLint * v);
	DRIFTGL_EXPORT void glScissorIndexed(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glScissorIndexedv(GLuint index, GLint * v);
	DRIFTGL_EXPORT void glDepthRangeArrayv(GLuint first, GLsizei count, GLdouble * v);
	DRIFTGL_EXPORT void glDepthRangeIndexed(GLuint index, GLdouble n, GLdouble f);
	DRIFTGL_EXPORT void glGetFloati_v(GLenum target, GLuint index, GLfloat * data);
	DRIFTGL_EXPORT void glGetDoublei_v(GLenum target, GLuint index, GLdouble * data);
	DRIFTGL_EXPORT void glDrawArraysInstancedBaseInstance(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance);
	DRIFTGL_EXPORT void glDrawElementsInstancedBaseInstance(GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount, GLuint baseinstance);
	DRIFTGL_EXPORT void glDrawElementsInstancedBaseVertexBaseInstance(GLenum mode, GLsizei count, GLenum type, const void * indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance);
	DRIFTGL_EXPORT void glGetInternalformativ(GLenum target, GLenum internalformat, GLenum pname, GLsizei bufSize, GLint * params);
	DRIFTGL_EXPORT void glGetActiveAtomicCounterBufferiv(GLuint program, GLuint bufferIndex, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glBindImageTexture(GLuint unit, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLenum format);
	DRIFTGL_EXPORT void glMemoryBarrier(GLbitfield barriers);
	DRIFTGL_EXPORT void glTexStorage1D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width);
	DRIFTGL_EXPORT void glTexStorage2D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glTexStorage3D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth);
	DRIFTGL_EXPORT void glDrawTransformFeedbackInstanced(GLenum mode, GLuint id, GLsizei instancecount);
	DRIFTGL_EXPORT void glDrawTransformFeedbackStreamInstanced(GLenum mode, GLuint id, GLuint stream, GLsizei instancecount);
	DRIFTGL_EXPORT void glClearBufferData(GLenum target, GLenum internalformat, GLenum format, GLenum type, const void * data);
	DRIFTGL_EXPORT void glClearBufferSubData(GLenum target, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void * data);
	DRIFTGL_EXPORT void glDispatchCompute(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z);
	DRIFTGL_EXPORT void glDispatchComputeIndirect(GLintptr indirect);
	DRIFTGL_EXPORT void glCopyImageSubData(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth);
	DRIFTGL_EXPORT void glFramebufferParameteri(GLenum target, GLenum pname, GLint param);
	DRIFTGL_EXPORT void glGetFramebufferParameteriv(GLenum target, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetInternalformati64v(GLenum target, GLenum internalformat, GLenum pname, GLsizei bufSize, GLint64 * params);
	DRIFTGL_EXPORT void glInvalidateTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth);
	DRIFTGL_EXPORT void glInvalidateTexImage(GLuint texture, GLint level);
	DRIFTGL_EXPORT void glInvalidateBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr length);
	DRIFTGL_EXPORT void glInvalidateBufferData(GLuint buffer);
	DRIFTGL_EXPORT void glInvalidateFramebuffer(GLenum target, GLsizei numAttachments, GLenum * attachments);
	DRIFTGL_EXPORT void glInvalidateSubFramebuffer(GLenum target, GLsizei numAttachments, GLenum * attachments, GLint x, GLint y, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glMultiDrawArraysIndirect(GLenum mode, const void * indirect, GLsizei drawcount, GLsizei stride);
	DRIFTGL_EXPORT void glMultiDrawElementsIndirect(GLenum mode, GLenum type, const void * indirect, GLsizei drawcount, GLsizei stride);
	DRIFTGL_EXPORT void glGetProgramInterfaceiv(GLuint program, GLenum programInterface, GLenum pname, GLint * params);
	DRIFTGL_EXPORT GLuint glGetProgramResourceIndex(GLuint program, GLenum programInterface, GLchar * name);
	DRIFTGL_EXPORT void glGetProgramResourceName(GLuint program, GLenum programInterface, GLuint index, GLsizei bufSize, GLsizei * length, GLchar * name);
	DRIFTGL_EXPORT void glGetProgramResourceiv(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, GLenum * props, GLsizei bufSize, GLsizei * length, GLint * params);
	DRIFTGL_EXPORT GLint glGetProgramResourceLocation(GLuint program, GLenum programInterface, GLchar * name);
	DRIFTGL_EXPORT GLint glGetProgramResourceLocationIndex(GLuint program, GLenum programInterface, GLchar * name);
	DRIFTGL_EXPORT void glShaderStorageBlockBinding(GLuint program, GLuint storageBlockIndex, GLuint storageBlockBinding);
	DRIFTGL_EXPORT void glTexBufferRange(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size);
	DRIFTGL_EXPORT void glTexStorage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations);
	DRIFTGL_EXPORT void glTexStorage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations);
	DRIFTGL_EXPORT void glTextureView(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers);
	DRIFTGL_EXPORT void glBindVertexBuffer(GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride);
	DRIFTGL_EXPORT void glVertexAttribFormat(GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset);
	DRIFTGL_EXPORT void glVertexAttribIFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
	DRIFTGL_EXPORT void glVertexAttribLFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
	DRIFTGL_EXPORT void glVertexAttribBinding(GLuint attribindex, GLuint bindingindex);
	DRIFTGL_EXPORT void glVertexBindingDivisor(GLuint bindingindex, GLuint divisor);
	DRIFTGL_EXPORT void glDebugMessageControl(GLenum source, GLenum type, GLenum severity, GLsizei count, GLuint * ids, GLboolean enabled);
	DRIFTGL_EXPORT void glDebugMessageInsert(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, GLchar * buf);
	DRIFTGL_EXPORT void glDebugMessageCallback(GLDEBUGPROC callback, const void * userParam);
	DRIFTGL_EXPORT GLuint glGetDebugMessageLog(GLuint count, GLsizei bufSize, GLenum * sources, GLenum * types, GLuint * ids, GLenum * severities, GLsizei * lengths, GLchar * messageLog);
	DRIFTGL_EXPORT void glPushDebugGroup(GLenum source, GLuint id, GLsizei length, GLchar * message);
	DRIFTGL_EXPORT void glPopDebugGroup();
	DRIFTGL_EXPORT void glObjectLabel(GLenum identifier, GLuint name, GLsizei length, GLchar * label);
	DRIFTGL_EXPORT void glGetObjectLabel(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei * length, GLchar * label);
	DRIFTGL_EXPORT void glObjectPtrLabel(const void * ptr, GLsizei length, GLchar * label);
	DRIFTGL_EXPORT void glGetObjectPtrLabel(const void * ptr, GLsizei bufSize, GLsizei * length, GLchar * label);
	DRIFTGL_EXPORT void glGetPointerv(GLenum pname, void ** params);
	DRIFTGL_EXPORT void glBufferStorage(GLenum target, GLsizeiptr size, const void * data, GLbitfield flags);
	DRIFTGL_EXPORT void glClearTexImage(GLuint texture, GLint level, GLenum format, GLenum type, const void * data);
	DRIFTGL_EXPORT void glClearTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void * data);
	DRIFTGL_EXPORT void glBindBuffersBase(GLenum target, GLuint first, GLsizei count, GLuint * buffers);
	DRIFTGL_EXPORT void glBindBuffersRange(GLenum target, GLuint first, GLsizei count, GLuint * buffers, GLintptr * offsets, GLsizeiptr * sizes);
	DRIFTGL_EXPORT void glBindTextures(GLuint first, GLsizei count, GLuint * textures);
	DRIFTGL_EXPORT void glBindSamplers(GLuint first, GLsizei count, GLuint * samplers);
	DRIFTGL_EXPORT void glBindImageTextures(GLuint first, GLsizei count, GLuint * textures);
	DRIFTGL_EXPORT void glBindVertexBuffers(GLuint first, GLsizei count, GLuint * buffers, GLintptr * offsets, GLsizei * strides);
	DRIFTGL_EXPORT void glClipControl(GLenum origin, GLenum depth);
	DRIFTGL_EXPORT void glCreateTransformFeedbacks(GLsizei n, GLuint * ids);
	DRIFTGL_EXPORT void glTransformFeedbackBufferBase(GLuint xfb, GLuint index, GLuint buffer);
	DRIFTGL_EXPORT void glTransformFeedbackBufferRange(GLuint xfb, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size);
	DRIFTGL_EXPORT void glGetTransformFeedbackiv(GLuint xfb, GLenum pname, GLint * param);
	DRIFTGL_EXPORT void glGetTransformFeedbacki_v(GLuint xfb, GLenum pname, GLuint index, GLint * param);
	DRIFTGL_EXPORT void glGetTransformFeedbacki64_v(GLuint xfb, GLenum pname, GLuint index, GLint64 * param);
	DRIFTGL_EXPORT void glCreateBuffers(GLsizei n, GLuint * buffers);
	DRIFTGL_EXPORT void glNamedBufferStorage(GLuint buffer, GLsizeiptr size, const void * data, GLbitfield flags);
	DRIFTGL_EXPORT void glNamedBufferData(GLuint buffer, GLsizeiptr size, const void * data, GLenum usage);
	DRIFTGL_EXPORT void glNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, const void * data);
	DRIFTGL_EXPORT void glCopyNamedBufferSubData(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size);
	DRIFTGL_EXPORT void glClearNamedBufferData(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void * data);
	DRIFTGL_EXPORT void glClearNamedBufferSubData(GLuint buffer, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void * data);
	DRIFTGL_EXPORT void * glMapNamedBuffer(GLuint buffer, GLenum access);
	DRIFTGL_EXPORT void * glMapNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access);
	DRIFTGL_EXPORT GLboolean glUnmapNamedBuffer(GLuint buffer);
	DRIFTGL_EXPORT void glFlushMappedNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length);
	DRIFTGL_EXPORT void glGetNamedBufferParameteriv(GLuint buffer, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetNamedBufferParameteri64v(GLuint buffer, GLenum pname, GLint64 * params);
	DRIFTGL_EXPORT void glGetNamedBufferPointerv(GLuint buffer, GLenum pname, void ** params);
	DRIFTGL_EXPORT void glGetNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, void * data);
	DRIFTGL_EXPORT void glCreateFramebuffers(GLsizei n, GLuint * framebuffers);
	DRIFTGL_EXPORT void glNamedFramebufferRenderbuffer(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
	DRIFTGL_EXPORT void glNamedFramebufferParameteri(GLuint framebuffer, GLenum pname, GLint param);
	DRIFTGL_EXPORT void glNamedFramebufferTexture(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level);
	DRIFTGL_EXPORT void glNamedFramebufferTextureLayer(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer);
	DRIFTGL_EXPORT void glNamedFramebufferDrawBuffer(GLuint framebuffer, GLenum buf);
	DRIFTGL_EXPORT void glNamedFramebufferDrawBuffers(GLuint framebuffer, GLsizei n, GLenum * bufs);
	DRIFTGL_EXPORT void glNamedFramebufferReadBuffer(GLuint framebuffer, GLenum src);
	DRIFTGL_EXPORT void glInvalidateNamedFramebufferData(GLuint framebuffer, GLsizei numAttachments, GLenum * attachments);
	DRIFTGL_EXPORT void glInvalidateNamedFramebufferSubData(GLuint framebuffer, GLsizei numAttachments, GLenum * attachments, GLint x, GLint y, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glClearNamedFramebufferiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLint * value);
	DRIFTGL_EXPORT void glClearNamedFramebufferuiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLuint * value);
	DRIFTGL_EXPORT void glClearNamedFramebufferfv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat * value);
	DRIFTGL_EXPORT void glClearNamedFramebufferfi(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil);
	DRIFTGL_EXPORT void glBlitNamedFramebuffer(GLuint readFramebuffer, GLuint drawFramebuffer, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter);
	DRIFTGL_EXPORT GLenum glCheckNamedFramebufferStatus(GLuint framebuffer, GLenum target);
	DRIFTGL_EXPORT void glGetNamedFramebufferParameteriv(GLuint framebuffer, GLenum pname, GLint * param);
	DRIFTGL_EXPORT void glGetNamedFramebufferAttachmentParameteriv(GLuint framebuffer, GLenum attachment, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glCreateRenderbuffers(GLsizei n, GLuint * renderbuffers);
	DRIFTGL_EXPORT void glNamedRenderbufferStorage(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glNamedRenderbufferStorageMultisample(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glGetNamedRenderbufferParameteriv(GLuint renderbuffer, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glCreateTextures(GLenum target, GLsizei n, GLuint * textures);
	DRIFTGL_EXPORT void glTextureBuffer(GLuint texture, GLenum internalformat, GLuint buffer);
	DRIFTGL_EXPORT void glTextureBufferRange(GLuint texture, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size);
	DRIFTGL_EXPORT void glTextureStorage1D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width);
	DRIFTGL_EXPORT void glTextureStorage2D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glTextureStorage3D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth);
	DRIFTGL_EXPORT void glTextureStorage2DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations);
	DRIFTGL_EXPORT void glTextureStorage3DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations);
	DRIFTGL_EXPORT void glTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void * pixels);
	DRIFTGL_EXPORT void glTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void * pixels);
	DRIFTGL_EXPORT void glTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void * pixels);
	DRIFTGL_EXPORT void glCompressedTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void * data);
	DRIFTGL_EXPORT void glCompressedTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void * data);
	DRIFTGL_EXPORT void glCompressedTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void * data);
	DRIFTGL_EXPORT void glCopyTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width);
	DRIFTGL_EXPORT void glCopyTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glCopyTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);
	DRIFTGL_EXPORT void glTextureParameterf(GLuint texture, GLenum pname, GLfloat param);
	DRIFTGL_EXPORT void glTextureParameterfv(GLuint texture, GLenum pname, GLfloat * param);
	DRIFTGL_EXPORT void glTextureParameteri(GLuint texture, GLenum pname, GLint param);
	DRIFTGL_EXPORT void glTextureParameterIiv(GLuint texture, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glTextureParameterIuiv(GLuint texture, GLenum pname, GLuint * params);
	DRIFTGL_EXPORT void glTextureParameteriv(GLuint texture, GLenum pname, GLint * param);
	DRIFTGL_EXPORT void glGenerateTextureMipmap(GLuint texture);
	DRIFTGL_EXPORT void glBindTextureUnit(GLuint unit, GLuint texture);
	DRIFTGL_EXPORT void glGetTextureImage(GLuint texture, GLint level, GLenum format, GLenum type, GLsizei bufSize, void * pixels);
	DRIFTGL_EXPORT void glGetCompressedTextureImage(GLuint texture, GLint level, GLsizei bufSize, void * pixels);
	DRIFTGL_EXPORT void glGetTextureLevelParameterfv(GLuint texture, GLint level, GLenum pname, GLfloat * params);
	DRIFTGL_EXPORT void glGetTextureLevelParameteriv(GLuint texture, GLint level, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetTextureParameterfv(GLuint texture, GLenum pname, GLfloat * params);
	DRIFTGL_EXPORT void glGetTextureParameterIiv(GLuint texture, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glGetTextureParameterIuiv(GLuint texture, GLenum pname, GLuint * params);
	DRIFTGL_EXPORT void glGetTextureParameteriv(GLuint texture, GLenum pname, GLint * params);
	DRIFTGL_EXPORT void glCreateVertexArrays(GLsizei n, GLuint * arrays);
	DRIFTGL_EXPORT void glDisableVertexArrayAttrib(GLuint vaobj, GLuint index);
	DRIFTGL_EXPORT void glEnableVertexArrayAttrib(GLuint vaobj, GLuint index);
	DRIFTGL_EXPORT void glVertexArrayElementBuffer(GLuint vaobj, GLuint buffer);
	DRIFTGL_EXPORT void glVertexArrayVertexBuffer(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride);
	DRIFTGL_EXPORT void glVertexArrayVertexBuffers(GLuint vaobj, GLuint first, GLsizei count, GLuint * buffers, GLintptr * offsets, GLsizei * strides);
	DRIFTGL_EXPORT void glVertexArrayAttribBinding(GLuint vaobj, GLuint attribindex, GLuint bindingindex);
	DRIFTGL_EXPORT void glVertexArrayAttribFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset);
	DRIFTGL_EXPORT void glVertexArrayAttribIFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
	DRIFTGL_EXPORT void glVertexArrayAttribLFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
	DRIFTGL_EXPORT void glVertexArrayBindingDivisor(GLuint vaobj, GLuint bindingindex, GLuint divisor);
	DRIFTGL_EXPORT void glGetVertexArrayiv(GLuint vaobj, GLenum pname, GLint * param);
	DRIFTGL_EXPORT void glGetVertexArrayIndexediv(GLuint vaobj, GLuint index, GLenum pname, GLint * param);
	DRIFTGL_EXPORT void glGetVertexArrayIndexed64iv(GLuint vaobj, GLuint index, GLenum pname, GLint64 * param);
	DRIFTGL_EXPORT void glCreateSamplers(GLsizei n, GLuint * samplers);
	DRIFTGL_EXPORT void glCreateProgramPipelines(GLsizei n, GLuint * pipelines);
	DRIFTGL_EXPORT void glCreateQueries(GLenum target, GLsizei n, GLuint * ids);
	DRIFTGL_EXPORT void glGetQueryBufferObjecti64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
	DRIFTGL_EXPORT void glGetQueryBufferObjectiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
	DRIFTGL_EXPORT void glGetQueryBufferObjectui64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
	DRIFTGL_EXPORT void glGetQueryBufferObjectuiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
	DRIFTGL_EXPORT void glMemoryBarrierByRegion(GLbitfield barriers);
	DRIFTGL_EXPORT void glGetTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, GLsizei bufSize, void * pixels);
	DRIFTGL_EXPORT void glGetCompressedTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei bufSize, void * pixels);
	DRIFTGL_EXPORT GLenum glGetGraphicsResetStatus();
	DRIFTGL_EXPORT void glGetnCompressedTexImage(GLenum target, GLint lod, GLsizei bufSize, void * pixels);
	DRIFTGL_EXPORT void glGetnTexImage(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void * pixels);
	DRIFTGL_EXPORT void glGetnUniformdv(GLuint program, GLint location, GLsizei bufSize, GLdouble * params);
	DRIFTGL_EXPORT void glGetnUniformfv(GLuint program, GLint location, GLsizei bufSize, GLfloat * params);
	DRIFTGL_EXPORT void glGetnUniformiv(GLuint program, GLint location, GLsizei bufSize, GLint * params);
	DRIFTGL_EXPORT void glGetnUniformuiv(GLuint program, GLint location, GLsizei bufSize, GLuint * params);
	DRIFTGL_EXPORT void glReadnPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void * data);
	DRIFTGL_EXPORT void glGetnMapdv(GLenum target, GLenum query, GLsizei bufSize, GLdouble * v);
	DRIFTGL_EXPORT void glGetnMapfv(GLenum target, GLenum query, GLsizei bufSize, GLfloat * v);
	DRIFTGL_EXPORT void glGetnMapiv(GLenum target, GLenum query, GLsizei bufSize, GLint * v);
	DRIFTGL_EXPORT void glGetnPixelMapfv(GLenum map, GLsizei bufSize, GLfloat * values);
	DRIFTGL_EXPORT void glGetnPixelMapuiv(GLenum map, GLsizei bufSize, GLuint * values);
	DRIFTGL_EXPORT void glGetnPixelMapusv(GLenum map, GLsizei bufSize, GLushort * values);
	DRIFTGL_EXPORT void glGetnPolygonStipple(GLsizei bufSize, GLubyte * pattern);
	DRIFTGL_EXPORT void glGetnColorTable(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void * table);
	DRIFTGL_EXPORT void glGetnConvolutionFilter(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void * image);
	DRIFTGL_EXPORT void glGetnSeparableFilter(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void * row, GLsizei columnBufSize, void * column, void * span);
	DRIFTGL_EXPORT void glGetnHistogram(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void * values);
	DRIFTGL_EXPORT void glGetnMinmax(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void * values);
	DRIFTGL_EXPORT void glTextureBarrier();
	DRIFTGL_EXPORT void glSpecializeShader(GLuint shader, GLchar * pEntryPoint, GLuint numSpecializationConstants, GLuint * pConstantIndex, GLuint * pConstantValue);
	DRIFTGL_EXPORT void glMultiDrawArraysIndirectCount(GLenum mode, const void * indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride);
	DRIFTGL_EXPORT void glMultiDrawElementsIndirectCount(GLenum mode, GLenum type, const void * indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride);
	DRIFTGL_EXPORT void glPolygonOffsetClamp(GLfloat factor, GLfloat units, GLfloat clamp);
	
	namespace procs {
		typedef void* (LookupFunctionPointer(const char* functionName));
		void Initialize(LookupFunctionPointer lookupFunctionPointer);
	}
}

#endif
